# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/heat_pump/ble/v1/get_data.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'device/heat_pump/ble/v1/get_data.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .....util.v1 import uuid_pb2 as util_dot_v1_dot_uuid__pb2
from ....power.ble.v1 import power_installation_state_pb2 as device_dot_power_dot_ble_dot_v1_dot_power__installation__state__pb2
from ...state.v1 import state_pb2 as device_dot_heat__pump_dot_state_dot_v1_dot_state__pb2
from ...config.v1.ccv.v1 import ccv_config_pb2 as device_dot_heat__pump_dot_config_dot_v1_dot_ccv_dot_v1_dot_ccv__config__pb2
from . import wifi_networks_pb2 as device_dot_heat__pump_dot_ble_dot_v1_dot_wifi__networks__pb2
from . import system_check_state_pb2 as device_dot_heat__pump_dot_ble_dot_v1_dot_system__check__state__pb2
from . import main_pump_flow_pb2 as device_dot_heat__pump_dot_ble_dot_v1_dot_main__pump__flow__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&device/heat_pump/ble/v1/get_data.proto\x12\x17\x64\x65vice.heat_pump.ble.v1\x1a\x12util/v1/uuid.proto\x1a\x32\x64\x65vice/power/ble/v1/power_installation_state.proto\x1a%device/heat_pump/state/v1/state.proto\x1a\x32\x64\x65vice/heat_pump/config/v1/ccv/v1/ccv_config.proto\x1a+device/heat_pump/ble/v1/wifi_networks.proto\x1a\x30\x64\x65vice/heat_pump/ble/v1/system_check_state.proto\x1a,device/heat_pump/ble/v1/main_pump_flow.proto\"\xdc\x03\n\x0c\x44\x61taResponse\x12\x39\n\x05\x65rror\x18\x05 \x01(\x0e\x32*.device.heat_pump.ble.v1.DataResponseError\x12\x31\n\x05state\x18\x01 \x01(\x0b\x32 .device.heat_pump.state.v1.StateH\x00\x12G\n\x12system_check_state\x18\x02 \x01(\x0b\x32).device.heat_pump.ble.v1.SystemCheckStateH\x00\x12:\n\tflow_data\x18\x03 \x01(\x0b\x32%.device.heat_pump.ble.v1.MainPumpFlowH\x00\x12>\n\rwifi_networks\x18\x04 \x01(\x0b\x32%.device.heat_pump.ble.v1.WifiNetworksH\x00\x12>\n\x06\x63onfig\x18\x06 \x01(\x0b\x32,.device.heat_pump.config.v1.ccv.v1.CcvConfigH\x00\x12O\n\x18power_installation_state\x18\x07 \x01(\x0b\x32+.device.power.ble.v1.PowerInstallationStateH\x00\x42\x08\n\x06group0\"b\n\x07GetData\x12!\n\nmessage_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\x12\x34\n\tdata_type\x18\x02 \x01(\x0e\x32!.device.heat_pump.ble.v1.DataType*\xaa\x01\n\x11\x44\x61taResponseError\x12#\n\x1f\x44\x41TA_RESPONSE_ERROR_UNSPECIFIED\x10\x00\x12%\n!DATA_RESPONSE_ERROR_NOT_SUPPORTED\x10\x01\x12%\n!DATA_RESPONSE_ERROR_NOT_AVAILABLE\x10\x02\x12\"\n\x1e\x44\x41TA_RESPONSE_ERROR_READ_ERROR\x10\x03*\xd7\x01\n\x08\x44\x61taType\x12\x19\n\x15\x44\x41TA_TYPE_UNSPECIFIED\x10\x00\x12\x13\n\x0f\x44\x41TA_TYPE_STATE\x10\x01\x12 \n\x1c\x44\x41TA_TYPE_SYSTEM_CHECK_STATE\x10\x02\x12\x17\n\x13\x44\x41TA_TYPE_FLOW_DATA\x10\x03\x12\x1b\n\x17\x44\x41TA_TYPE_WIFI_NETWORKS\x10\x04\x12\x1b\n\x17\x44\x41TA_TYPE_CONFIGURATION\x10\x05\x12&\n\"DATA_TYPE_POWER_INSTALLATION_STATE\x10\x06\x42\xa2\x01\n\x17\x64\x65vice.heat_pump.ble.v1B\x0cGetDataProtoP\x01\xa2\x02\x03\x44HB\xaa\x02\x16\x44\x65vice.HeatPump.Ble.V1\xca\x02\x16\x44\x65vice\\HeatPump\\Ble\\V1\xe2\x02\"Device\\HeatPump\\Ble\\V1\\GPBMetadata\xea\x02\x19\x44\x65vice::HeatPump::Ble::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.heat_pump.ble.v1.get_data_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027device.heat_pump.ble.v1B\014GetDataProtoP\001\242\002\003DHB\252\002\026Device.HeatPump.Ble.V1\312\002\026Device\\HeatPump\\Ble\\V1\342\002\"Device\\HeatPump\\Ble\\V1\\GPBMetadata\352\002\031Device::HeatPump::Ble::V1'
  _globals['_DATARESPONSEERROR']._serialized_start=951
  _globals['_DATARESPONSEERROR']._serialized_end=1121
  _globals['_DATATYPE']._serialized_start=1124
  _globals['_DATATYPE']._serialized_end=1339
  _globals['_DATARESPONSE']._serialized_start=372
  _globals['_DATARESPONSE']._serialized_end=848
  _globals['_GETDATA']._serialized_start=850
  _globals['_GETDATA']._serialized_end=948
# @@protoc_insertion_point(module_scope)


"""Custom exceptions for the Aira Home library."""
# utils/exceptions.py


class NotLoggedInException(Exception):
    """Exception raised when a user is not logged in."""
    pass

class AuthenticationError(Exception):
    """Exception raised for authentication errors."""
    pass

class UnknownTypeException(Exception):
    """Exception raised for unknown types."""
    pass

class UnknownCommandException(Exception):
    """Exception raised for unknown commands."""
    pass

class TokenError(Exception):
    """Exception raised for token errors."""
    pass

class BLEDiscoveryError(Exception):
    """Exception raised for BLE discovery errors."""
    pass

class BLEConnectionError(Exception):
    """Exception raised for BLE connection errors."""
    pass

class BLEInitializationError(Exception):
    """Exception raised for BLE initialization errors."""
    pass


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/heat_pump/config/v1/ccv/v1/ccv_config.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'device/heat_pump/config/v1/ccv/v1/ccv_config.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import heat_curve_pb2 as device_dot_heat__pump_dot_config_dot_v1_dot_ccv_dot_v1_dot_heat__curve__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2device/heat_pump/config/v1/ccv/v1/ccv_config.proto\x12!device.heat_pump.config.v1.ccv.v1\x1a\x32\x64\x65vice/heat_pump/config/v1/ccv/v1/heat_curve.proto\"\xa2\x08\n\tCcvConfig\x12H\n\x0esensor_sources\x18\x01 \x01(\x0b\x32\x30.device.heat_pump.config.v1.ccv.v1.SensorSources\x12R\n\x13\x63ompressor_settings\x18\x02 \x01(\x0b\x32\x35.device.heat_pump.config.v1.ccv.v1.CompressorSettings\x12H\n\x0eheating_system\x18\x07 \x01(\x0b\x32\x30.device.heat_pump.config.v1.ccv.v1.HeatingSystem\x12@\n\ndhw_system\x18\x08 \x01(\x0b\x32,.device.heat_pump.config.v1.ccv.v1.DhwSystem\x12>\n\taway_mode\x18\t \x01(\x0b\x32+.device.heat_pump.config.v1.ccv.v1.AwayMode\x12J\n\x0fheating_cooling\x18\n \x01(\x0b\x32\x31.device.heat_pump.config.v1.ccv.v1.HeatingCooling\x12M\n\x11outdoor_unit_size\x18\r \x01(\x0e\x32\x32.device.heat_pump.config.v1.ccv.v1.OutdoorUnitSize\x12Q\n\x13pump_speed_settings\x18\x0e \x01(\x0b\x32\x34.device.heat_pump.config.v1.ccv.v1.PumpSpeedSettings\x12L\n\x10\x61larm_thresholds\x18\x0f \x01(\x0b\x32\x32.device.heat_pump.config.v1.ccv.v1.AlarmThresholds\x12N\n\x11\x65lectricity_meter\x18\x10 \x01(\x0b\x32\x33.device.heat_pump.config.v1.ccv.v1.ElectricityMeter\x12\x46\n\rinline_heater\x18\x11 \x01(\x0b\x32/.device.heat_pump.config.v1.ccv.v1.InlineHeater\x12@\n\nnight_mode\x18\x12 \x01(\x0b\x32,.device.heat_pump.config.v1.ccv.v1.NightMode\x12\x42\n\x0b\x66low_meters\x18\x13 \x01(\x0b\x32-.device.heat_pump.config.v1.ccv.v1.FlowMeters\x12Q\n\x13\x65nergy_balance_kick\x18\x14 \x01(\x0b\x32\x34.device.heat_pump.config.v1.ccv.v1.EnergyBalanceKick\"k\n\x11\x45nergyBalanceKick\x12\x1a\n\x12time_between_kicks\x18\x01 \x01(\r\x12\x1b\n\x13kick_temperature_up\x18\x02 \x01(\x02\x12\x1d\n\x15kick_temperature_down\x18\x03 \x01(\x02\"\xc7\x03\n\nFlowMeters\x12P\n\x0bmeter1_type\x18\x01 \x01(\x0e\x32;.device.heat_pump.config.v1.ccv.v1.FlowMeters.FlowMeterType\x12P\n\x0bmeter2_type\x18\x02 \x01(\x0e\x32;.device.heat_pump.config.v1.ccv.v1.FlowMeters.FlowMeterType\"\x94\x02\n\rFlowMeterType\x12\x1f\n\x1b\x46LOW_METER_TYPE_UNSPECIFIED\x10\x00\x12!\n\x1d\x46LOW_METER_TYPE_NOT_CONNECTED\x10\x01\x12$\n FLOW_METER_TYPE_HUBA_DN20_BRONZE\x10\x02\x12$\n FLOW_METER_TYPE_HUBA_DN25_BRONZE\x10\x03\x12%\n!FLOW_METER_TYPE_HUBA_DN20_PLASTIC\x10\x04\x12%\n!FLOW_METER_TYPE_HUBA_DN25_PLASTIC\x10\x05\x12%\n!FLOW_METER_TYPE_HUBA_DN10_PLASTIC\x10\x06\"\x1c\n\tNightMode\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\"\xa1\x03\n\x0cInlineHeater\x12P\n\x05step1\x18\x01 \x01(\x0e\x32\x41.device.heat_pump.config.v1.ccv.v1.InlineHeater.InlineHeaterUsage\x12P\n\x05step2\x18\x02 \x01(\x0e\x32\x41.device.heat_pump.config.v1.ccv.v1.InlineHeater.InlineHeaterUsage\x12P\n\x05step3\x18\x03 \x01(\x0e\x32\x41.device.heat_pump.config.v1.ccv.v1.InlineHeater.InlineHeaterUsage\"\x9a\x01\n\x11InlineHeaterUsage\x12#\n\x1fINLINE_HEATER_USAGE_UNSPECIFIED\x10\x00\x12 \n\x1cINLINE_HEATER_USAGE_DISABLED\x10\x01\x12\x1e\n\x1aINLINE_HEATER_USAGE_BACKUP\x10\x02\x12\x1e\n\x1aINLINE_HEATER_USAGE_NORMAL\x10\x03\"\x90\x02\n\x10\x45lectricityMeter\x12V\n\x04type\x18\x01 \x01(\x0e\x32H.device.heat_pump.config.v1.ccv.v1.ElectricityMeter.ElectricityMeterType\"\xa3\x01\n\x14\x45lectricityMeterType\x12&\n\"ELECTRICITY_METER_TYPE_UNSPECIFIED\x10\x00\x12\x1f\n\x1b\x45LECTRICITY_METER_TYPE_NONE\x10\x01\x12 \n\x1c\x45LECTRICITY_METER_TYPE_ET340\x10\x02\x12 \n\x1c\x45LECTRICITY_METER_TYPE_ET112\x10\x03\"f\n\x0f\x41larmThresholds\x12\x1b\n\x13\x66low_level1_low12kw\x18\x01 \x01(\x02\x12\x1a\n\x12\x66low_level1_low8kw\x18\x02 \x01(\x02\x12\x1a\n\x12\x66low_level1_low6kw\x18\x03 \x01(\x02\"x\n\x11PumpSpeedSettings\x12\x0f\n\x07heating\x18\x01 \x01(\x05\x12\x0f\n\x07\x63ooling\x18\x02 \x01(\x05\x12\x0f\n\x07\x64\x65\x66rost\x18\x03 \x01(\x05\x12\x0f\n\x07minimum\x18\x04 \x01(\x05\x12\x12\n\nlegionella\x18\x05 \x01(\x05\x12\x0b\n\x03\x64hw\x18\x06 \x01(\x05\"\xe4\x03\n\x0eHeatingCooling\x12\x11\n\tnum_zones\x18\x01 \x01(\x05\x12\x32\n*ambient_temperature_to_enable_heating_mode\x18\x03 \x01(\x02\x12\x32\n*ambient_temperature_to_enable_cooling_mode\x18\x04 \x01(\x02\x12+\n#minimum_time_heating_cooling_switch\x18\x06 \x01(\x05\x12\x33\n+supply_temperature_too_high_alarm_temp_diff\x18\x07 \x01(\x02\x12/\n\'supply_temperature_too_high_alarm_delay\x18\x08 \x01(\x05\x12G\n\x0esettings_zone1\x18\t \x01(\x0b\x32/.device.heat_pump.config.v1.ccv.v1.ZoneSettings\x12G\n\x0esettings_zone2\x18\n \x01(\x0b\x32/.device.heat_pump.config.v1.ccv.v1.ZoneSettings\x12\x32\n*ambient_temperature_to_allow_inline_heater\x18\x0b \x01(\x02\"P\n\x08\x41wayMode\x12#\n\x1b\x64hw_tank_temperature_change\x18\x02 \x01(\x02\x12\x1f\n\x17room_temperature_change\x18\x03 \x01(\x02\"\xbf\x03\n\x0cZoneSettings\x12&\n\x1a\x64\x65precated_control_enabled\x18\x01 \x01(\x08\x42\x02\x18\x01\x12G\n\x07heating\x18\x03 \x01(\x0b\x32\x36.device.heat_pump.config.v1.ccv.v1.ZoneHeatingSettings\x12G\n\x07\x63ooling\x18\x04 \x01(\x0b\x32\x36.device.heat_pump.config.v1.ccv.v1.ZoneCoolingSettings\x12I\n\x11room_pi_regulator\x18\x05 \x01(\x0b\x32..device.heat_pump.config.v1.ccv.v1.PiRegulator\x12`\n$deprecated_mixing_valve_pi_regulator\x18\x06 \x01(\x0b\x32..device.heat_pump.config.v1.ccv.v1.PiRegulatorB\x02\x18\x01\x12H\n\x0cmixing_valve\x18\x07 \x01(\x0b\x32\x32.device.heat_pump.config.v1.ccv.v1.ZoneMixingValve\"\xd0\x01\n\x13ZoneCoolingSettings\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x15\n\rroom_setpoint\x18\x02 \x01(\x02\x12\x1f\n\x17minimum_supply_setpoint\x18\x03 \x01(\x02\x12\x1f\n\x17maximum_supply_setpoint\x18\x04 \x01(\x02\x12O\n\ncool_curve\x18\x05 \x01(\x0b\x32;.device.heat_pump.config.v1.ccv.v1.PiecewiseLinearCoolCurve\"\xd0\x01\n\x13ZoneHeatingSettings\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x15\n\rroom_setpoint\x18\x02 \x01(\x02\x12\x1f\n\x17minimum_supply_setpoint\x18\x03 \x01(\x02\x12\x1f\n\x17maximum_supply_setpoint\x18\x04 \x01(\x02\x12O\n\nheat_curve\x18\x05 \x01(\x0b\x32;.device.heat_pump.config.v1.ccv.v1.PiecewiseLinearHeatCurve\"\xdc\x01\n\x0fZoneMixingValve\x12\x1e\n\x16regulation_period_time\x18\x01 \x01(\x05\x12\x1f\n\x17\x65nd_to_end_running_time\x18\x02 \x01(\x05\x12)\n!minimum_relay_output_pulse_length\x18\x03 \x01(\x05\x12\x17\n\x0f\x63ontrol_enabled\x18\x04 \x01(\x08\x12\x44\n\x0cpi_regulator\x18\x05 \x01(\x0b\x32..device.heat_pump.config.v1.ccv.v1.PiRegulator\"\x8b\x03\n\tDhwSystem\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x14\n\x0c\x64hw_setpoint\x18\x02 \x01(\x02\x12\x19\n\x11\x64hw_setpoint_diff\x18\x03 \x01(\x02\x12G\n\x05\x62oost\x18\x04 \x01(\x0b\x32\x38.device.heat_pump.config.v1.ccv.v1.DomesticHotWaterBoost\x12%\n\x1dtank_temperature_night_change\x18\x05 \x01(\x02\x12!\n\x19\x63ompressor_speed_dhw_mode\x18\x06 \x01(\x05\x12$\n\x1cmaximum_setpoint_temperature\x18\x07 \x01(\x02\x12/\n\'unacknowledged_alarm_temperature_change\x18\x08 \x01(\x02\x12R\n\x13legionella_settings\x18\t \x01(\x0b\x32\x35.device.heat_pump.config.v1.ccv.v1.LegionellaSettings\"\xab\x01\n\x12LegionellaSettings\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x1b\n\x13interval_time_start\x18\x02 \x01(\x05\x12\x1a\n\x12interval_time_stop\x18\x03 \x01(\x05\x12\x18\n\x10maximum_duration\x18\x04 \x01(\x05\x12\x1a\n\x12target_temperature\x18\x05 \x01(\x02\x12\x15\n\rinterval_days\x18\x06 \x01(\x05\"\xb2\x02\n\rHeatingSystem\x12\x14\n\x0cheating_time\x18\x01 \x01(\x05\x12\x10\n\x08\x64hw_time\x18\x02 \x01(\x05\x12\x41\n9minimum_inline_heater_cooling_time_before_compressor_stop\x18\x04 \x01(\x05\x12\x17\n\x0fheat_balance_a0\x18\x05 \x01(\x05\x12\x17\n\x0fheat_balance_a2\x18\x06 \x01(\x05\x12\x14\n\x0c\x63ooling_time\x18\x07 \x01(\x05\x12\x17\n\x0f\x63ool_balance_k0\x18\x08 \x01(\x05\x12U\n\x1d\x63ompressor_speed_pi_regulator\x18\t \x01(\x0b\x32..device.heat_pump.config.v1.ccv.v1.PiRegulator\"1\n\x0bPiRegulator\x12\x10\n\x08p_factor\x18\x01 \x01(\x02\x12\x10\n\x08i_factor\x18\x02 \x01(\x02\"d\n\x15\x44omesticHotWaterBoost\x12+\n\x1f\x64\x65precated_remaining_boost_time\x18\x01 \x01(\x05\x42\x02\x18\x01\x12\x1e\n\x16tank_temp_boost_change\x18\x02 \x01(\x02\"\x93\x05\n\x12\x43ompressorSettings\x12\"\n\x16\x64\x65precated_speed_level\x18\x01 \x01(\x05\x42\x02\x18\x01\x12#\n\x17\x64\x65precated_working_mode\x18\x02 \x01(\x05\x42\x02\x18\x01\x12&\n\x1eminimum_time_start_start_cycle\x18\x03 \x01(\x05\x12%\n\x1dminimum_time_stop_start_cycle\x18\x04 \x01(\x05\x12!\n\x19p0_compressor_prerun_time\x18\x05 \x01(\x05\x12\'\n\x1f\x64hw_diverting_valve_prerun_time\x18\x06 \x01(\x05\x12#\n\x1bp0_compressor_afterrun_time\x18\x07 \x01(\x05\x12%\n\x1d\x64iverting_valve_afterrun_time\x18\x08 \x01(\x05\x12 \n\x18p0_autostart_temperature\x18\t \x01(\x02\x12\"\n\x1amaximum_outlet_temperature\x18\n \x01(\x02\x12\"\n\x1aminimum_outlet_temperature\x18\x0b \x01(\x02\x12!\n\x19maximum_inlet_temperature\x18\x0c \x01(\x02\x12!\n\x19minimum_inlet_temperature\x18\r \x01(\x02\x12&\n\x1eminimum_inner_coil_temperature\x18\x0e \x01(\x02\x12,\n deprecated_compressor_limit_time\x18\x0f \x01(\x05\x42\x02\x18\x01\x12(\n compressor_inner_coil_block_time\x18\x10 \x01(\x05\x12\x1d\n\x15\x63ompressor_limit_time\x18\x11 \x01(\x02\"\x84\x04\n\rSensorSources\x12/\n\'outdoor_unit_ambient_temperature_source\x18\x01 \x01(\r\x12.\n&outdoor_unit_supply_temperature_source\x18\x02 \x01(\r\x12.\n&outdoor_unit_return_temperature_source\x18\x03 \x01(\r\x12\x32\n*outdoor_unit_inner_coil_temperature_source\x18\x04 \x01(\r\x12/\n\'indoor_unit_dhw_tank_temperature_source\x18\x05 \x01(\r\x12-\n%indoor_unit_supply_temperature_source\x18\x06 \x01(\r\x12\x33\n+indoor_unit_supply_temperature_zone1_source\x18\x07 \x01(\r\x12\x33\n+indoor_unit_supply_temperature_zone2_source\x18\x08 \x01(\r\x12\x31\n)indoor_unit_room_temperature_zone1_source\x18\t \x01(\r\x12\x31\n)indoor_unit_room_temperature_zone2_source\x18\n \x01(\r*\x95\x01\n\x0fOutdoorUnitSize\x12!\n\x1dOUTDOOR_UNIT_SIZE_UNSPECIFIED\x10\x00\x12\x1e\n\x1aOUTDOOR_UNIT_SIZE_AIRA_6KW\x10\x01\x12\x1e\n\x1aOUTDOOR_UNIT_SIZE_AIRA_8KW\x10\x02\x12\x1f\n\x1bOUTDOOR_UNIT_SIZE_AIRA_12KW\x10\x03\x42\xd8\x01\n!device.heat_pump.config.v1.ccv.v1B\x0e\x43\x63vConfigProtoP\x01\xa2\x02\x03\x43VC\xaa\x02 Device.HeatPump.Config.V1.Ccv.V1\xca\x02 Device\\HeatPump\\Config\\V1\\Ccv\\V1\xe2\x02,Device\\HeatPump\\Config\\V1\\Ccv\\V1\\GPBMetadata\xea\x02%Device::HeatPump::Config::V1::Ccv::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.heat_pump.config.v1.ccv.v1.ccv_config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!device.heat_pump.config.v1.ccv.v1B\016CcvConfigProtoP\001\242\002\003CVC\252\002 Device.HeatPump.Config.V1.Ccv.V1\312\002 Device\\HeatPump\\Config\\V1\\Ccv\\V1\342\002,Device\\HeatPump\\Config\\V1\\Ccv\\V1\\GPBMetadata\352\002%Device::HeatPump::Config::V1::Ccv::V1'
  _globals['_ZONESETTINGS'].fields_by_name['deprecated_control_enabled']._loaded_options = None
  _globals['_ZONESETTINGS'].fields_by_name['deprecated_control_enabled']._serialized_options = b'\030\001'
  _globals['_ZONESETTINGS'].fields_by_name['deprecated_mixing_valve_pi_regulator']._loaded_options = None
  _globals['_ZONESETTINGS'].fields_by_name['deprecated_mixing_valve_pi_regulator']._serialized_options = b'\030\001'
  _globals['_DOMESTICHOTWATERBOOST'].fields_by_name['deprecated_remaining_boost_time']._loaded_options = None
  _globals['_DOMESTICHOTWATERBOOST'].fields_by_name['deprecated_remaining_boost_time']._serialized_options = b'\030\001'
  _globals['_COMPRESSORSETTINGS'].fields_by_name['deprecated_speed_level']._loaded_options = None
  _globals['_COMPRESSORSETTINGS'].fields_by_name['deprecated_speed_level']._serialized_options = b'\030\001'
  _globals['_COMPRESSORSETTINGS'].fields_by_name['deprecated_working_mode']._loaded_options = None
  _globals['_COMPRESSORSETTINGS'].fields_by_name['deprecated_working_mode']._serialized_options = b'\030\001'
  _globals['_COMPRESSORSETTINGS'].fields_by_name['deprecated_compressor_limit_time']._loaded_options = None
  _globals['_COMPRESSORSETTINGS'].fields_by_name['deprecated_compressor_limit_time']._serialized_options = b'\030\001'
  _globals['_OUTDOORUNITSIZE']._serialized_start=6600
  _globals['_OUTDOORUNITSIZE']._serialized_end=6749
  _globals['_CCVCONFIG']._serialized_start=142
  _globals['_CCVCONFIG']._serialized_end=1200
  _globals['_ENERGYBALANCEKICK']._serialized_start=1202
  _globals['_ENERGYBALANCEKICK']._serialized_end=1309
  _globals['_FLOWMETERS']._serialized_start=1312
  _globals['_FLOWMETERS']._serialized_end=1767
  _globals['_FLOWMETERS_FLOWMETERTYPE']._serialized_start=1491
  _globals['_FLOWMETERS_FLOWMETERTYPE']._serialized_end=1767
  _globals['_NIGHTMODE']._serialized_start=1769
  _globals['_NIGHTMODE']._serialized_end=1797
  _globals['_INLINEHEATER']._serialized_start=1800
  _globals['_INLINEHEATER']._serialized_end=2217
  _globals['_INLINEHEATER_INLINEHEATERUSAGE']._serialized_start=2063
  _globals['_INLINEHEATER_INLINEHEATERUSAGE']._serialized_end=2217
  _globals['_ELECTRICITYMETER']._serialized_start=2220
  _globals['_ELECTRICITYMETER']._serialized_end=2492
  _globals['_ELECTRICITYMETER_ELECTRICITYMETERTYPE']._serialized_start=2329
  _globals['_ELECTRICITYMETER_ELECTRICITYMETERTYPE']._serialized_end=2492
  _globals['_ALARMTHRESHOLDS']._serialized_start=2494
  _globals['_ALARMTHRESHOLDS']._serialized_end=2596
  _globals['_PUMPSPEEDSETTINGS']._serialized_start=2598
  _globals['_PUMPSPEEDSETTINGS']._serialized_end=2718
  _globals['_HEATINGCOOLING']._serialized_start=2721
  _globals['_HEATINGCOOLING']._serialized_end=3205
  _globals['_AWAYMODE']._serialized_start=3207
  _globals['_AWAYMODE']._serialized_end=3287
  _globals['_ZONESETTINGS']._serialized_start=3290
  _globals['_ZONESETTINGS']._serialized_end=3737
  _globals['_ZONECOOLINGSETTINGS']._serialized_start=3740
  _globals['_ZONECOOLINGSETTINGS']._serialized_end=3948
  _globals['_ZONEHEATINGSETTINGS']._serialized_start=3951
  _globals['_ZONEHEATINGSETTINGS']._serialized_end=4159
  _globals['_ZONEMIXINGVALVE']._serialized_start=4162
  _globals['_ZONEMIXINGVALVE']._serialized_end=4382
  _globals['_DHWSYSTEM']._serialized_start=4385
  _globals['_DHWSYSTEM']._serialized_end=4780
  _globals['_LEGIONELLASETTINGS']._serialized_start=4783
  _globals['_LEGIONELLASETTINGS']._serialized_end=4954
  _globals['_HEATINGSYSTEM']._serialized_start=4957
  _globals['_HEATINGSYSTEM']._serialized_end=5263
  _globals['_PIREGULATOR']._serialized_start=5265
  _globals['_PIREGULATOR']._serialized_end=5314
  _globals['_DOMESTICHOTWATERBOOST']._serialized_start=5316
  _globals['_DOMESTICHOTWATERBOOST']._serialized_end=5416
  _globals['_COMPRESSORSETTINGS']._serialized_start=5419
  _globals['_COMPRESSORSETTINGS']._serialized_end=6078
  _globals['_SENSORSOURCES']._serialized_start=6081
  _globals['_SENSORSOURCES']._serialized_end=6597
# @@protoc_insertion_point(module_scope)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/heat_pump/command/v1/modbus.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'device/heat_pump/command/v1/modbus.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(device/heat_pump/command/v1/modbus.proto\x12\x1b\x64\x65vice.heat_pump.command.v1\"O\n\x0eModbusResponse\x12=\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32/.device.heat_pump.command.v1.ModbusRegisterData\"\xa3\x01\n\x12ModbusRegisterData\x12\x0e\n\x04\x63oil\x18\x01 \x01(\x08H\x00\x12\x0e\n\x04\x62yte\x18\x02 \x01(\rH\x00\x12\x15\n\x0bsigned_byte\x18\x03 \x01(\x11H\x00\x12\x0e\n\x04word\x18\x04 \x01(\rH\x00\x12\x15\n\x0bsigned_word\x18\x05 \x01(\x11H\x00\x12\x0e\n\x04long\x18\x06 \x01(\rH\x00\x12\x15\n\x0bsigned_long\x18\x07 \x01(\x11H\x00\x42\x08\n\x06group0\"\x9b\x02\n\rModbusRequest\x12\x35\n\x04unit\x18\x01 \x01(\x0e\x32\'.device.heat_pump.command.v1.ModbusUnit\x12=\n\x08\x66unction\x18\x02 \x01(\x0e\x32+.device.heat_pump.command.v1.ModbusFunction\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\r\x12=\n\x04\x64\x61ta\x18\x04 \x01(\x0b\x32/.device.heat_pump.command.v1.ModbusRegisterData\x12\x44\n\x0breturn_type\x18\x05 \x01(\x0e\x32/.device.heat_pump.command.v1.ModbusRegisterType*\xa8\x02\n\x12ModbusRegisterType\x12$\n MODBUS_REGISTER_TYPE_UNSPECIFIED\x10\x00\x12\x1d\n\x19MODBUS_REGISTER_TYPE_COIL\x10\x01\x12\x1d\n\x19MODBUS_REGISTER_TYPE_BYTE\x10\x02\x12$\n MODBUS_REGISTER_TYPE_SIGNED_BYTE\x10\x03\x12\x1d\n\x19MODBUS_REGISTER_TYPE_WORD\x10\x04\x12$\n MODBUS_REGISTER_TYPE_SIGNED_WORD\x10\x05\x12\x1d\n\x19MODBUS_REGISTER_TYPE_LONG\x10\x06\x12$\n MODBUS_REGISTER_TYPE_SIGNED_LONG\x10\x07*\xd5\x01\n\x0eModbusFunction\x12\x1f\n\x1bMODBUS_FUNCTION_UNSPECIFIED\x10\x00\x12\x1d\n\x19MODBUS_FUNCTION_READ_COIL\x10\x01\x12 \n\x1cMODBUS_FUNCTION_READ_HOLDING\x10\x03\x12\x1e\n\x1aMODBUS_FUNCTION_READ_INPUT\x10\x04\x12\x1e\n\x1aMODBUS_FUNCTION_WRITE_COIL\x10\x05\x12!\n\x1dMODBUS_FUNCTION_WRITE_HOLDING\x10\x06*l\n\nModbusUnit\x12\x1b\n\x17MODBUS_UNIT_UNSPECIFIED\x10\x00\x12\x12\n\x0eMODBUS_UNIT_CM\x10\x64\x12\x13\n\x0fMODBUS_UNIT_CCV\x10\x7f\x12\x18\n\x13MODBUS_UNIT_OUTDOOR\x10\x82\x01\x42\xb5\x01\n\x1b\x64\x65vice.heat_pump.command.v1B\x0bModbusProtoP\x01\xa2\x02\x03\x44HC\xaa\x02\x1a\x44\x65vice.HeatPump.Command.V1\xca\x02\x1a\x44\x65vice\\HeatPump\\Command\\V1\xe2\x02&Device\\HeatPump\\Command\\V1\\GPBMetadata\xea\x02\x1d\x44\x65vice::HeatPump::Command::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.heat_pump.command.v1.modbus_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033device.heat_pump.command.v1B\013ModbusProtoP\001\242\002\003DHC\252\002\032Device.HeatPump.Command.V1\312\002\032Device\\HeatPump\\Command\\V1\342\002&Device\\HeatPump\\Command\\V1\\GPBMetadata\352\002\035Device::HeatPump::Command::V1'
  _globals['_MODBUSREGISTERTYPE']._serialized_start=607
  _globals['_MODBUSREGISTERTYPE']._serialized_end=903
  _globals['_MODBUSFUNCTION']._serialized_start=906
  _globals['_MODBUSFUNCTION']._serialized_end=1119
  _globals['_MODBUSUNIT']._serialized_start=1121
  _globals['_MODBUSUNIT']._serialized_end=1229
  _globals['_MODBUSRESPONSE']._serialized_start=73
  _globals['_MODBUSRESPONSE']._serialized_end=152
  _globals['_MODBUSREGISTERDATA']._serialized_start=155
  _globals['_MODBUSREGISTERDATA']._serialized_end=318
  _globals['_MODBUSREQUEST']._serialized_start=321
  _globals['_MODBUSREQUEST']._serialized_end=604
# @@protoc_insertion_point(module_scope)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/wall_thermostat/broadcast/v1/wall_thermostat_update.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'device/wall_thermostat/broadcast/v1/wall_thermostat_update.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@device/wall_thermostat/broadcast/v1/wall_thermostat_update.proto\x12#device.wall_thermostat.broadcast.v1\"\xa5\x01\n\x12WallThermostatInfo\x12\x12\n\nfw_version\x18\x01 \x01(\r\x12\x1a\n\x12\x62ootloader_version\x18\x02 \x01(\r\x12\x14\n\x0cwakeup_count\x18\x03 \x01(\r\x12\x14\n\x0creboot_count\x18\x04 \x01(\r\x12\x1a\n\x12setpoint_set_count\x18\x05 \x01(\r\x12\x17\n\x0f\x64hw_boost_count\x18\x06 \x01(\r\"\xae\x01\n\x14WallThermostatUpdate\x12\x1a\n\x12\x61\x63tual_temperature\x18\x01 \x01(\x05\x12\x10\n\x08humidity\x18\x02 \x01(\r\x12!\n\x19warning_low_battery_level\x18\x03 \x01(\x08\x12\x45\n\x04info\x18\x04 \x01(\x0b\x32\x37.device.wall_thermostat.broadcast.v1.WallThermostatInfoB\xeb\x01\n#device.wall_thermostat.broadcast.v1B\x19WallThermostatUpdateProtoP\x01\xa2\x02\x03\x44WB\xaa\x02\"Device.WallThermostat.Broadcast.V1\xca\x02\"Device\\WallThermostat\\Broadcast\\V1\xe2\x02.Device\\WallThermostat\\Broadcast\\V1\\GPBMetadata\xea\x02%Device::WallThermostat::Broadcast::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.wall_thermostat.broadcast.v1.wall_thermostat_update_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#device.wall_thermostat.broadcast.v1B\031WallThermostatUpdateProtoP\001\242\002\003DWB\252\002\"Device.WallThermostat.Broadcast.V1\312\002\"Device\\WallThermostat\\Broadcast\\V1\342\002.Device\\WallThermostat\\Broadcast\\V1\\GPBMetadata\352\002%Device::WallThermostat::Broadcast::V1'
  _globals['_WALLTHERMOSTATINFO']._serialized_start=106
  _globals['_WALLTHERMOSTATINFO']._serialized_end=271
  _globals['_WALLTHERMOSTATUPDATE']._serialized_start=274
  _globals['_WALLTHERMOSTATUPDATE']._serialized_end=448
# @@protoc_insertion_point(module_scope)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/v1/online.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'device/v1/online.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x64\x65vice/v1/online.proto\x12\tdevice.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"B\n\x06Online\x12\x0e\n\x06online\x18\x01 \x01(\x08\x12(\n\x04time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB]\n\tdevice.v1B\x0bOnlineProtoP\x01\xa2\x02\x03\x44XX\xaa\x02\tDevice.V1\xca\x02\tDevice\\V1\xe2\x02\x15\x44\x65vice\\V1\\GPBMetadata\xea\x02\nDevice::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.v1.online_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\tdevice.v1B\013OnlineProtoP\001\242\002\003DXX\252\002\tDevice.V1\312\002\tDevice\\V1\342\002\025Device\\V1\\GPBMetadata\352\002\nDevice::V1'
  _globals['_ONLINE']._serialized_start=70
  _globals['_ONLINE']._serialized_end=136
# @@protoc_insertion_point(module_scope)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/power/ble/v1/power_installation_state.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'device/power/ble/v1/power_installation_state.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...peripheral.photovoltaics.v1 import config_pb2 as device_dot_power_dot_peripheral_dot_photovoltaics_dot_v1_dot_config__pb2
from ...peripheral.battery.v1 import config_pb2 as device_dot_power_dot_peripheral_dot_battery_dot_v1_dot_config__pb2
from ...grid.v1 import grid_code_preset_pb2 as device_dot_power_dot_grid_dot_v1_dot_grid__code__preset__pb2
from ...grid.v1 import config_pb2 as device_dot_power_dot_grid_dot_v1_dot_config__pb2
from ...controller.v1 import system_mode_pb2 as device_dot_power_dot_controller_dot_v1_dot_system__mode__pb2
from ...controller.v1 import current_transformer_pb2 as device_dot_power_dot_controller_dot_v1_dot_current__transformer__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2device/power/ble/v1/power_installation_state.proto\x12\x13\x64\x65vice.power.ble.v1\x1a\x35\x64\x65vice/power/peripheral/photovoltaics/v1/config.proto\x1a/device/power/peripheral/battery/v1/config.proto\x1a+device/power/grid/v1/grid_code_preset.proto\x1a!device/power/grid/v1/config.proto\x1a,device/power/controller/v1/system_mode.proto\x1a\x34\x64\x65vice/power/controller/v1/current_transformer.proto\"\xab\x02\n\x14RuntimeConfiguration\x12\x34\n\x04mode\x18\x01 \x01(\x0e\x32&.device.power.controller.v1.SystemMode\x12\x35\n\x0bgrid_config\x18\x03 \x01(\x0b\x32 .device.power.grid.v1.GridConfig\x12I\n\x0e\x62\x61ttery_config\x18\x04 \x01(\x0b\x32\x31.device.power.peripheral.battery.v1.BatteryConfig\x12[\n\x14photovoltaics_config\x18\x05 \x01(\x0b\x32=.device.power.peripheral.photovoltaics.v1.PhotovoltaicsConfig\"i\n\x08Inverter\x12\x12\n\nproduct_id\x18\x01 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\x14\n\x0cpower_rating\x18\x03 \x01(\x02\x12\x16\n\x0e\x63urrent_rating\x18\x04 \x01(\x02\x12\n\n\x02id\x18\x05 \x01(\t\"\x96\x01\n\x07\x42\x61ttery\x12\x12\n\nproduct_id\x18\x01 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\x14\n\x0cpower_rating\x18\x03 \x01(\x02\x12\x17\n\x0f\x63\x61pacity_rating\x18\x04 \x01(\x02\x12\x15\n\rc_rate_rating\x18\x05 \x01(\x02\x12\x14\n\x0cmanufacturer\x18\x06 \x01(\x05\x12\n\n\x02id\x18\x08 \x01(\t\"V\n\rPhotovoltaics\x12\x12\n\nproduct_id\x18\x01 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\x14\n\x0cpower_rating\x18\x03 \x01(\x02\x12\n\n\x02id\x18\x04 \x01(\t\"\xab\x01\n\x0cPowerDevices\x12/\n\x08inverter\x18\x01 \x03(\x0b\x32\x1d.device.power.ble.v1.Inverter\x12\x39\n\rphotovoltaics\x18\x02 \x03(\x0b\x32\".device.power.ble.v1.Photovoltaics\x12/\n\tbatteries\x18\x03 \x03(\x0b\x32\x1c.device.power.ble.v1.Battery\"\xad\x01\n\x15\x46\x61\x63ilityConfiguration\x12\x11\n\tmain_fuse\x18\x01 \x01(\x02\x12?\n\x06phases\x18\x02 \x01(\x0e\x32/.device.power.ble.v1.FacilityPhaseConfiguration\x12\x1f\n\x17\x61\x63tive_power_rating_neg\x18\x03 \x01(\x02\x12\x1f\n\x17\x61\x63tive_power_rating_pos\x18\x04 \x01(\x02\"\xd2\x03\n\x16PowerInstallationState\x12\x1a\n\x12paired_core_serial\x18\x01 \x01(\t\x12\x1f\n\x17paired_core_app_version\x18\x02 \x01(\t\x12>\n\x10grid_code_preset\x18\x03 \x01(\x0e\x32$.device.power.grid.v1.GridCodePreset\x12J\n\x16\x66\x61\x63ility_configuration\x18\x04 \x01(\x0b\x32*.device.power.ble.v1.FacilityConfiguration\x12\x32\n\x07\x64\x65vices\x18\x05 \x01(\x0b\x32!.device.power.ble.v1.PowerDevices\x12\x19\n\x11microgrid_powered\x18\x06 \x01(\x08\x12V\n\x19\x63urrent_transformer_state\x18\x07 \x01(\x0b\x32\x33.device.power.controller.v1.CurrentTransformerState\x12H\n\x15runtime_configuration\x18\x08 \x01(\x0b\x32).device.power.ble.v1.RuntimeConfiguration*\x9b\x01\n\x1a\x46\x61\x63ilityPhaseConfiguration\x12,\n(FACILITY_PHASE_CONFIGURATION_UNSPECIFIED\x10\x00\x12\'\n#FACILITY_PHASE_CONFIGURATION_SINGLE\x10\x01\x12&\n\"FACILITY_PHASE_CONFIGURATION_THREE\x10\x02\x42\xa1\x01\n\x13\x64\x65vice.power.ble.v1B\x1bPowerInstallationStateProtoP\x01\xa2\x02\x03\x44PB\xaa\x02\x13\x44\x65vice.Power.Ble.V1\xca\x02\x13\x44\x65vice\\Power\\Ble\\V1\xe2\x02\x1f\x44\x65vice\\Power\\Ble\\V1\\GPBMetadata\xea\x02\x16\x44\x65vice::Power::Ble::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.power.ble.v1.power_installation_state_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\023device.power.ble.v1B\033PowerInstallationStateProtoP\001\242\002\003DPB\252\002\023Device.Power.Ble.V1\312\002\023Device\\Power\\Ble\\V1\342\002\037Device\\Power\\Ble\\V1\\GPBMetadata\352\002\026Device::Power::Ble::V1'
  _globals['_FACILITYPHASECONFIGURATION']._serialized_start=1829
  _globals['_FACILITYPHASECONFIGURATION']._serialized_end=1984
  _globals['_RUNTIMECONFIGURATION']._serialized_start=360
  _globals['_RUNTIMECONFIGURATION']._serialized_end=659
  _globals['_INVERTER']._serialized_start=661
  _globals['_INVERTER']._serialized_end=766
  _globals['_BATTERY']._serialized_start=769
  _globals['_BATTERY']._serialized_end=919
  _globals['_PHOTOVOLTAICS']._serialized_start=921
  _globals['_PHOTOVOLTAICS']._serialized_end=1007
  _globals['_POWERDEVICES']._serialized_start=1010
  _globals['_POWERDEVICES']._serialized_end=1181
  _globals['_FACILITYCONFIGURATION']._serialized_start=1184
  _globals['_FACILITYCONFIGURATION']._serialized_end=1357
  _globals['_POWERINSTALLATIONSTATE']._serialized_start=1360
  _globals['_POWERINSTALLATIONSTATE']._serialized_end=1826
# @@protoc_insertion_point(module_scope)


# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from . import service_pb2 as device_dot_heat__pump_dot_statistics_dot_v1_dot_service__pb2

GRPC_GENERATED_VERSION = '1.72.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in device/heat_pump/statistics/v1/service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class HeatPumpStatisticsServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetHeatPumpInsights = channel.unary_unary(
                '/device.heat_pump.statistics.v1.HeatPumpStatisticsService/GetHeatPumpInsights',
                request_serializer=device_dot_heat__pump_dot_statistics_dot_v1_dot_service__pb2.GetHeatPumpInsightsRequest.SerializeToString,
                response_deserializer=device_dot_heat__pump_dot_statistics_dot_v1_dot_service__pb2.GetHeatPumpInsightsResponse.FromString,
                _registered_method=True)
        self.GetCop = channel.unary_unary(
                '/device.heat_pump.statistics.v1.HeatPumpStatisticsService/GetCop',
                request_serializer=device_dot_heat__pump_dot_statistics_dot_v1_dot_service__pb2.GetCopRequest.SerializeToString,
                response_deserializer=device_dot_heat__pump_dot_statistics_dot_v1_dot_service__pb2.GetCopResponse.FromString,
                _registered_method=True)
        self.GetOptimisationSavings = channel.unary_unary(
                '/device.heat_pump.statistics.v1.HeatPumpStatisticsService/GetOptimisationSavings',
                request_serializer=device_dot_heat__pump_dot_statistics_dot_v1_dot_service__pb2.GetOptimisationSavingsRequest.SerializeToString,
                response_deserializer=device_dot_heat__pump_dot_statistics_dot_v1_dot_service__pb2.GetOptimisationSavingsResponse.FromString,
                _registered_method=True)
        self.GetSavings = channel.unary_unary(
                '/device.heat_pump.statistics.v1.HeatPumpStatisticsService/GetSavings',
                request_serializer=device_dot_heat__pump_dot_statistics_dot_v1_dot_service__pb2.GetSavingsRequest.SerializeToString,
                response_deserializer=device_dot_heat__pump_dot_statistics_dot_v1_dot_service__pb2.GetSavingsResponse.FromString,
                _registered_method=True)


class HeatPumpStatisticsServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetHeatPumpInsights(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCop(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOptimisationSavings(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSavings(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_HeatPumpStatisticsServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetHeatPumpInsights': grpc.unary_unary_rpc_method_handler(
                    servicer.GetHeatPumpInsights,
                    request_deserializer=device_dot_heat__pump_dot_statistics_dot_v1_dot_service__pb2.GetHeatPumpInsightsRequest.FromString,
                    response_serializer=device_dot_heat__pump_dot_statistics_dot_v1_dot_service__pb2.GetHeatPumpInsightsResponse.SerializeToString,
            ),
            'GetCop': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCop,
                    request_deserializer=device_dot_heat__pump_dot_statistics_dot_v1_dot_service__pb2.GetCopRequest.FromString,
                    response_serializer=device_dot_heat__pump_dot_statistics_dot_v1_dot_service__pb2.GetCopResponse.SerializeToString,
            ),
            'GetOptimisationSavings': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOptimisationSavings,
                    request_deserializer=device_dot_heat__pump_dot_statistics_dot_v1_dot_service__pb2.GetOptimisationSavingsRequest.FromString,
                    response_serializer=device_dot_heat__pump_dot_statistics_dot_v1_dot_service__pb2.GetOptimisationSavingsResponse.SerializeToString,
            ),
            'GetSavings': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSavings,
                    request_deserializer=device_dot_heat__pump_dot_statistics_dot_v1_dot_service__pb2.GetSavingsRequest.FromString,
                    response_serializer=device_dot_heat__pump_dot_statistics_dot_v1_dot_service__pb2.GetSavingsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'device.heat_pump.statistics.v1.HeatPumpStatisticsService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('device.heat_pump.statistics.v1.HeatPumpStatisticsService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class HeatPumpStatisticsService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetHeatPumpInsights(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/device.heat_pump.statistics.v1.HeatPumpStatisticsService/GetHeatPumpInsights',
            device_dot_heat__pump_dot_statistics_dot_v1_dot_service__pb2.GetHeatPumpInsightsRequest.SerializeToString,
            device_dot_heat__pump_dot_statistics_dot_v1_dot_service__pb2.GetHeatPumpInsightsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetCop(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/device.heat_pump.statistics.v1.HeatPumpStatisticsService/GetCop',
            device_dot_heat__pump_dot_statistics_dot_v1_dot_service__pb2.GetCopRequest.SerializeToString,
            device_dot_heat__pump_dot_statistics_dot_v1_dot_service__pb2.GetCopResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetOptimisationSavings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/device.heat_pump.statistics.v1.HeatPumpStatisticsService/GetOptimisationSavings',
            device_dot_heat__pump_dot_statistics_dot_v1_dot_service__pb2.GetOptimisationSavingsRequest.SerializeToString,
            device_dot_heat__pump_dot_statistics_dot_v1_dot_service__pb2.GetOptimisationSavingsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetSavings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/device.heat_pump.statistics.v1.HeatPumpStatisticsService/GetSavings',
            device_dot_heat__pump_dot_statistics_dot_v1_dot_service__pb2.GetSavingsRequest.SerializeToString,
            device_dot_heat__pump_dot_statistics_dot_v1_dot_service__pb2.GetSavingsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/power/controller/v1/system_mode.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'device/power/controller/v1/system_mode.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,device/power/controller/v1/system_mode.proto\x12\x1a\x64\x65vice.power.controller.v1*\x9f\x01\n\nSystemMode\x12\x1b\n\x17SYSTEM_MODE_UNSPECIFIED\x10\x00\x12\x17\n\x13SYSTEM_MODE_DEFAULT\x10\x01\x12 \n\x1cSYSTEM_MODE_SELF_CONSUMPTION\x10\x02\x12\x1c\n\x18SYSTEM_MODE_PEAK_SHAVING\x10\x03\x12\x1b\n\x17SYSTEM_MODE_MEASUREMENT\x10\x04\x42\xb8\x01\n\x1a\x64\x65vice.power.controller.v1B\x0fSystemModeProtoP\x01\xa2\x02\x03\x44PC\xaa\x02\x1a\x44\x65vice.Power.Controller.V1\xca\x02\x1a\x44\x65vice\\Power\\Controller\\V1\xe2\x02&Device\\Power\\Controller\\V1\\GPBMetadata\xea\x02\x1d\x44\x65vice::Power::Controller::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.power.controller.v1.system_mode_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032device.power.controller.v1B\017SystemModeProtoP\001\242\002\003DPC\252\002\032Device.Power.Controller.V1\312\002\032Device\\Power\\Controller\\V1\342\002&Device\\Power\\Controller\\V1\\GPBMetadata\352\002\035Device::Power::Controller::V1'
  _globals['_SYSTEMMODE']._serialized_start=77
  _globals['_SYSTEMMODE']._serialized_end=236
# @@protoc_insertion_point(module_scope)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/heat_pump/command/v1/command_progress.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'device/heat_pump/command/v1/command_progress.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .....util.v1 import uuid_pb2 as util_dot_v1_dot_uuid__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import modbus_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_modbus__pb2
from . import command_error_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_command__error__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2device/heat_pump/command/v1/command_progress.proto\x12\x1b\x64\x65vice.heat_pump.command.v1\x1a\x12util/v1/uuid.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a(device/heat_pump/command/v1/modbus.proto\x1a/device/heat_pump/command/v1/command_error.proto\"\xef\x04\n\x0f\x43ommandProgress\x12!\n\ncommand_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\x12(\n\x04time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x15\x61ws_iot_received_time\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12*\n\x08received\x18\x03 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12:\n\x05\x65rror\x18\x05 \x01(\x0b\x32).device.heat_pump.command.v1.CommandErrorH\x00\x12+\n\tsucceeded\x18\x06 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12&\n\x04sent\x18\x07 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\x31\n\x0f\x66ile_downloaded\x18\x08 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12/\n\rfile_uploaded\x18\t \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12/\n\rfile_verified\x18\n \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\x30\n\x0e\x66ile_installed\x18\x0b \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\x46\n\x0fmodbus_response\x18\x0c \x01(\x0b\x32+.device.heat_pump.command.v1.ModbusResponseH\x00\x42\x08\n\x06group0B\xbe\x01\n\x1b\x64\x65vice.heat_pump.command.v1B\x14\x43ommandProgressProtoP\x01\xa2\x02\x03\x44HC\xaa\x02\x1a\x44\x65vice.HeatPump.Command.V1\xca\x02\x1a\x44\x65vice\\HeatPump\\Command\\V1\xe2\x02&Device\\HeatPump\\Command\\V1\\GPBMetadata\xea\x02\x1d\x44\x65vice::HeatPump::Command::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.heat_pump.command.v1.command_progress_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033device.heat_pump.command.v1B\024CommandProgressProtoP\001\242\002\003DHC\252\002\032Device.HeatPump.Command.V1\312\002\032Device\\HeatPump\\Command\\V1\342\002&Device\\HeatPump\\Command\\V1\\GPBMetadata\352\002\035Device::HeatPump::Command::V1'
  _globals['_COMMANDPROGRESS']._serialized_start=257
  _globals['_COMMANDPROGRESS']._serialized_end=880
# @@protoc_insertion_point(module_scope)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: user_account/v2/user_account.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'user_account/v2/user_account.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...util.v2 import market_pb2 as util_dot_v2_dot_market__pb2
from ...util.v2 import locale_pb2 as util_dot_v2_dot_locale__pb2
from ...util.v1 import uuid_pb2 as util_dot_v1_dot_uuid__pb2
from . import role_pb2 as user__account_dot_v2_dot_role__pb2
from ...notification.v2 import notification_pb2 as notification_dot_v2_dot_notification__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"user_account/v2/user_account.proto\x12\x0fuser_account.v2\x1a\x14util/v2/market.proto\x1a\x14util/v2/locale.proto\x1a\x12util/v1/uuid.proto\x1a\x1auser_account/v2/role.proto\x1a\"notification/v2/notification.proto\x1a\x1fgoogle/protobuf/timestamp.proto\":\n\x17VerifyProximityResponse\x12\x1f\n\x17verification_successful\x18\x01 \x01(\x08\"D\n\x16VerifyProximityRequest\x12*\n\x13\x63lose_heat_pump_ids\x18\x01 \x03(\x0b\x32\r.util.v1.Uuid\"s\n&GetProximityVerificationStatusResponse\x12I\n\x13verification_status\x18\x01 \x01(\x0e\x32,.user_account.v2.ProximityVerificationStatus\"\'\n%GetProximityVerificationStatusRequest\"\x18\n\x16\x44\x65leteResidentResponse\"\x9d\x01\n\x15\x44\x65leteResidentRequest\x12)\n\x12\x65ngagement_user_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\x12#\n\x0chousehold_id\x18\x02 \x01(\x0b\x32\r.util.v1.Uuid\x12\x34\n\x1d\x64\x65leted_by_engagement_user_id\x18\x03 \x01(\x0b\x32\r.util.v1.Uuid\"\xb7\x01\n\x08Resident\x12)\n\x12\x65ngagement_user_id\x18\x02 \x01(\x0b\x32\r.util.v1.Uuid\x12#\n\x0chousehold_id\x18\x03 \x01(\x0b\x32\r.util.v1.Uuid\x12\x12\n\ngiven_name\x18\x04 \x01(\t\x12\x13\n\x0b\x66\x61mily_name\x18\x05 \x01(\t\x12\r\n\x05\x65mail\x18\x06 \x01(\t\x12#\n\x04role\x18\x07 \x01(\x0e\x32\x15.user_account.v2.Role\"%\n\x08HeatPump\x12\x19\n\x02id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\"\xb4\x01\n\tHousehold\x12\x19\n\x02id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\x12\x0c\n\x04name\x18\x02 \x01(\t\x12,\n\tresidents\x18\x03 \x03(\x0b\x32\x19.user_account.v2.Resident\x12,\n\theat_pump\x18\x04 \x01(\x0b\x32\x19.user_account.v2.HeatPump\x12\"\n\x0b\x66\x61\x63ility_id\x18\x05 \x01(\x0b\x32\r.util.v1.Uuid\"O\n\x1dGetHouseholdsByUserIdResponse\x12.\n\nhouseholds\x18\x01 \x03(\x0b\x32\x1a.user_account.v2.Household\"I\n\x1cGetHouseholdsByUserIdRequest\x12)\n\x12\x65ngagement_user_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\"n\n+UserHasAcceptedLatestLegalDocumentsResponse\x12?\n\nagreements\x18\x01 \x03(\x0b\x32+.user_account.v2.LegalDocumentUserAgreement\"L\n*UserHasAcceptedLatestLegalDocumentsRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\"*\n(CreateLegalDocumentUserAgreementResponse\"s\n\'CreateLegalDocumentUserAgreementRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\x12(\n\x11legal_document_id\x18\x02 \x01(\x0b\x32\r.util.v1.Uuid\"\xa5\x01\n\x1aLegalDocumentUserAgreement\x12\x1e\n\x07user_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\x12/\n\x0b\x61\x63\x63\x65pted_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x36\n\x0elegal_document\x18\x03 \x01(\x0b\x32\x1e.user_account.v2.LegalDocument\"\xc3\x01\n\rLegalDocument\x12\"\n\x0b\x64ocument_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\x12\x0f\n\x07version\x18\x02 \x01(\x05\x12\x39\n\rdocument_type\x18\x03 \x01(\x0e\x32\".user_account.v2.LegalDocumentType\x12\x0f\n\x07\x63ontent\x18\x04 \x01(\t\x12\x1f\n\x06market\x18\x05 \x01(\x0e\x32\x0f.util.v2.Market\x12\x10\n\x08web_link\x18\x06 \x01(\t\"O\n\x19UpdateUserAccountResponse\x12\x32\n\x0cuser_account\x18\x01 \x01(\x0b\x32\x1c.user_account.v2.UserAccount\"\xfc\x01\n\x18UpdateUserAccountRequest\x12\x1e\n\x07user_id\x18\x02 \x01(\x0b\x32\r.util.v1.Uuid\x12!\n\ncontact_id\x18\x03 \x01(\x0b\x32\r.util.v1.Uuid\x12\x14\n\x0cphone_number\x18\x04 \x01(\t\x12\x12\n\ngiven_name\x18\x05 \x01(\t\x12\x13\n\x0b\x66\x61mily_name\x18\x06 \x01(\t\x12\x1f\n\x06locale\x18\x07 \x01(\x0e\x32\x0f.util.v2.Locale\x12\x1f\n\x06market\x18\x08 \x01(\x0e\x32\x0f.util.v2.Market\x12\x1c\n\x14notification_enabled\x18\t \x01(\x08\"\x87\x01\n!GetUserAccountByCognitoIdResponse\x12\x32\n\x0cuser_account\x18\x02 \x01(\x0b\x32\x1c.user_account.v2.UserAccount\x12.\n\nhouseholds\x18\x03 \x03(\x0b\x32\x1a.user_account.v2.Household\"E\n GetUserAccountByCognitoIdRequest\x12!\n\ncognito_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\"\x96\x03\n\x0bUserAccount\x12\x1e\n\x07user_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\x12!\n\ncontact_id\x18\x02 \x01(\x0b\x32\r.util.v1.Uuid\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x14\n\x0cphone_number\x18\x04 \x01(\t\x12\x12\n\ngiven_name\x18\x05 \x01(\t\x12\x13\n\x0b\x66\x61mily_name\x18\x06 \x01(\t\x12\x1f\n\x06locale\x18\x08 \x01(\x0e\x32\x0f.util.v2.Locale\x12\x1f\n\x06market\x18\t \x01(\x0e\x32\x0f.util.v2.Market\x12\x1c\n\x14notification_enabled\x18\n \x01(\x08\x12!\n\ncognito_id\x18\x0b \x01(\x0b\x32\r.util.v1.Uuid\x12\x1e\n\x16phone_number_confirmed\x18\x0c \x01(\x08\x12S\n\x1dproximity_verification_status\x18\r \x01(\x0e\x32,.user_account.v2.ProximityVerificationStatus\"Z\n\"GetFeaturesAsNotificationsResponse\x12\x34\n\rnotifications\x18\x01 \x03(\x0b\x32\x1d.notification.v2.Notification\"D\n!GetFeaturesAsNotificationsRequest\x12\x1f\n\x06locale\x18\x01 \x01(\x0e\x32\x0f.util.v2.Locale\"\x1c\n\x1a\x43onfirmPhoneNumberResponse\"\x82\x01\n\x19\x43onfirmPhoneNumberRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\x12\x14\n\x0cphone_number\x18\x02 \x01(\t\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x03 \x01(\t\x12\x19\n\x11\x63onfirmation_code\x18\x04 \x01(\t\"\x1c\n\x1a\x43onfirmEmailChangeResponse\"\x7f\n\x19\x43onfirmEmailChangeRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\x12\x11\n\tnew_email\x18\x02 \x01(\t\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x03 \x01(\t\x12\x19\n\x11\x63onfirmation_code\x18\x04 \x01(\t\")\n\tZoneNames\x12\r\n\x05zone1\x18\x01 \x01(\t\x12\r\n\x05zone2\x18\x02 \x01(\t\"N\n\x1cGetHeatPumpZoneNamesResponse\x12.\n\nzone_names\x18\x01 \x01(\x0b\x32\x1a.user_account.v2.ZoneNames\"B\n\x1bGetHeatPumpZoneNamesRequest\x12#\n\x0cheat_pump_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid*\xd6\x01\n\x1bProximityVerificationStatus\x12-\n)PROXIMITY_VERIFICATION_STATUS_UNSPECIFIED\x10\x00\x12.\n*PROXIMITY_VERIFICATION_STATUS_NOT_VERIFIED\x10\x01\x12*\n&PROXIMITY_VERIFICATION_STATUS_VERIFIED\x10\x02\x12,\n(PROXIMITY_VERIFICATION_STATUS_NOT_NEEDED\x10\x03*\x8a\x01\n\x11LegalDocumentType\x12#\n\x1fLEGAL_DOCUMENT_TYPE_UNSPECIFIED\x10\x00\x12(\n$LEGAL_DOCUMENT_TYPE_TERMS_OF_SERVICE\x10\x01\x12&\n\"LEGAL_DOCUMENT_TYPE_PRIVACY_POLICY\x10\x02\x32\xf2\x0b\n\x12UserAccountService\x12\x82\x01\n\x19GetUserAccountByCognitoId\x12\x31.user_account.v2.GetUserAccountByCognitoIdRequest\x1a\x32.user_account.v2.GetUserAccountByCognitoIdResponse\x12m\n\x12\x43onfirmPhoneNumber\x12*.user_account.v2.ConfirmPhoneNumberRequest\x1a+.user_account.v2.ConfirmPhoneNumberResponse\x12j\n\x11UpdateUserAccount\x12).user_account.v2.UpdateUserAccountRequest\x1a*.user_account.v2.UpdateUserAccountResponse\x12m\n\x12\x43onfirmEmailChange\x12*.user_account.v2.ConfirmEmailChangeRequest\x1a+.user_account.v2.ConfirmEmailChangeResponse\x12\x85\x01\n\x1aGetFeaturesAsNotifications\x12\x32.user_account.v2.GetFeaturesAsNotificationsRequest\x1a\x33.user_account.v2.GetFeaturesAsNotificationsResponse\x12\x61\n\x0e\x44\x65leteResident\x12&.user_account.v2.DeleteResidentRequest\x1a\'.user_account.v2.DeleteResidentResponse\x12\x64\n\x0fVerifyProximity\x12\'.user_account.v2.VerifyProximityRequest\x1a(.user_account.v2.VerifyProximityResponse\x12s\n\x14GetHeatPumpZoneNames\x12,.user_account.v2.GetHeatPumpZoneNamesRequest\x1a-.user_account.v2.GetHeatPumpZoneNamesResponse\x12\xa0\x01\n#UserHasAcceptedLatestLegalDocuments\x12;.user_account.v2.UserHasAcceptedLatestLegalDocumentsRequest\x1a<.user_account.v2.UserHasAcceptedLatestLegalDocumentsResponse\x12\x97\x01\n CreateLegalDocumentUserAgreement\x12\x38.user_account.v2.CreateLegalDocumentUserAgreementRequest\x1a\x39.user_account.v2.CreateLegalDocumentUserAgreementResponse\x12v\n\x15GetHouseholdsByUserId\x12-.user_account.v2.GetHouseholdsByUserIdRequest\x1a..user_account.v2.GetHouseholdsByUserIdResponse\x12\x91\x01\n\x1eGetProximityVerificationStatus\x12\x36.user_account.v2.GetProximityVerificationStatusRequest\x1a\x37.user_account.v2.GetProximityVerificationStatusResponseB|\n\x0fuser_account.v2B\x10UserAccountProtoP\x01\xa2\x02\x03UXX\xaa\x02\x0eUserAccount.V2\xca\x02\x0eUserAccount\\V2\xe2\x02\x1aUserAccount\\V2\\GPBMetadata\xea\x02\x0fUserAccount::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'user_account.v2.user_account_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017user_account.v2B\020UserAccountProtoP\001\242\002\003UXX\252\002\016UserAccount.V2\312\002\016UserAccount\\V2\342\002\032UserAccount\\V2\\GPBMetadata\352\002\017UserAccount::V2'
  _globals['_PROXIMITYVERIFICATIONSTATUS']._serialized_start=3601
  _globals['_PROXIMITYVERIFICATIONSTATUS']._serialized_end=3815
  _globals['_LEGALDOCUMENTTYPE']._serialized_start=3818
  _globals['_LEGALDOCUMENTTYPE']._serialized_end=3956
  _globals['_VERIFYPROXIMITYRESPONSE']._serialized_start=216
  _globals['_VERIFYPROXIMITYRESPONSE']._serialized_end=274
  _globals['_VERIFYPROXIMITYREQUEST']._serialized_start=276
  _globals['_VERIFYPROXIMITYREQUEST']._serialized_end=344
  _globals['_GETPROXIMITYVERIFICATIONSTATUSRESPONSE']._serialized_start=346
  _globals['_GETPROXIMITYVERIFICATIONSTATUSRESPONSE']._serialized_end=461
  _globals['_GETPROXIMITYVERIFICATIONSTATUSREQUEST']._serialized_start=463
  _globals['_GETPROXIMITYVERIFICATIONSTATUSREQUEST']._serialized_end=502
  _globals['_DELETERESIDENTRESPONSE']._serialized_start=504
  _globals['_DELETERESIDENTRESPONSE']._serialized_end=528
  _globals['_DELETERESIDENTREQUEST']._serialized_start=531
  _globals['_DELETERESIDENTREQUEST']._serialized_end=688
  _globals['_RESIDENT']._serialized_start=691
  _globals['_RESIDENT']._serialized_end=874
  _globals['_HEATPUMP']._serialized_start=876
  _globals['_HEATPUMP']._serialized_end=913
  _globals['_HOUSEHOLD']._serialized_start=916
  _globals['_HOUSEHOLD']._serialized_end=1096
  _globals['_GETHOUSEHOLDSBYUSERIDRESPONSE']._serialized_start=1098
  _globals['_GETHOUSEHOLDSBYUSERIDRESPONSE']._serialized_end=1177
  _globals['_GETHOUSEHOLDSBYUSERIDREQUEST']._serialized_start=1179
  _globals['_GETHOUSEHOLDSBYUSERIDREQUEST']._serialized_end=1252
  _globals['_USERHASACCEPTEDLATESTLEGALDOCUMENTSRESPONSE']._serialized_start=1254
  _globals['_USERHASACCEPTEDLATESTLEGALDOCUMENTSRESPONSE']._serialized_end=1364
  _globals['_USERHASACCEPTEDLATESTLEGALDOCUMENTSREQUEST']._serialized_start=1366
  _globals['_USERHASACCEPTEDLATESTLEGALDOCUMENTSREQUEST']._serialized_end=1442
  _globals['_CREATELEGALDOCUMENTUSERAGREEMENTRESPONSE']._serialized_start=1444
  _globals['_CREATELEGALDOCUMENTUSERAGREEMENTRESPONSE']._serialized_end=1486
  _globals['_CREATELEGALDOCUMENTUSERAGREEMENTREQUEST']._serialized_start=1488
  _globals['_CREATELEGALDOCUMENTUSERAGREEMENTREQUEST']._serialized_end=1603
  _globals['_LEGALDOCUMENTUSERAGREEMENT']._serialized_start=1606
  _globals['_LEGALDOCUMENTUSERAGREEMENT']._serialized_end=1771
  _globals['_LEGALDOCUMENT']._serialized_start=1774
  _globals['_LEGALDOCUMENT']._serialized_end=1969
  _globals['_UPDATEUSERACCOUNTRESPONSE']._serialized_start=1971
  _globals['_UPDATEUSERACCOUNTRESPONSE']._serialized_end=2050
  _globals['_UPDATEUSERACCOUNTREQUEST']._serialized_start=2053
  _globals['_UPDATEUSERACCOUNTREQUEST']._serialized_end=2305
  _globals['_GETUSERACCOUNTBYCOGNITOIDRESPONSE']._serialized_start=2308
  _globals['_GETUSERACCOUNTBYCOGNITOIDRESPONSE']._serialized_end=2443
  _globals['_GETUSERACCOUNTBYCOGNITOIDREQUEST']._serialized_start=2445
  _globals['_GETUSERACCOUNTBYCOGNITOIDREQUEST']._serialized_end=2514
  _globals['_USERACCOUNT']._serialized_start=2517
  _globals['_USERACCOUNT']._serialized_end=2923
  _globals['_GETFEATURESASNOTIFICATIONSRESPONSE']._serialized_start=2925
  _globals['_GETFEATURESASNOTIFICATIONSRESPONSE']._serialized_end=3015
  _globals['_GETFEATURESASNOTIFICATIONSREQUEST']._serialized_start=3017
  _globals['_GETFEATURESASNOTIFICATIONSREQUEST']._serialized_end=3085
  _globals['_CONFIRMPHONENUMBERRESPONSE']._serialized_start=3087
  _globals['_CONFIRMPHONENUMBERRESPONSE']._serialized_end=3115
  _globals['_CONFIRMPHONENUMBERREQUEST']._serialized_start=3118
  _globals['_CONFIRMPHONENUMBERREQUEST']._serialized_end=3248
  _globals['_CONFIRMEMAILCHANGERESPONSE']._serialized_start=3250
  _globals['_CONFIRMEMAILCHANGERESPONSE']._serialized_end=3278
  _globals['_CONFIRMEMAILCHANGEREQUEST']._serialized_start=3280
  _globals['_CONFIRMEMAILCHANGEREQUEST']._serialized_end=3407
  _globals['_ZONENAMES']._serialized_start=3409
  _globals['_ZONENAMES']._serialized_end=3450
  _globals['_GETHEATPUMPZONENAMESRESPONSE']._serialized_start=3452
  _globals['_GETHEATPUMPZONENAMESRESPONSE']._serialized_end=3530
  _globals['_GETHEATPUMPZONENAMESREQUEST']._serialized_start=3532
  _globals['_GETHEATPUMPZONENAMESREQUEST']._serialized_end=3598
  _globals['_USERACCOUNTSERVICE']._serialized_start=3959
  _globals['_USERACCOUNTSERVICE']._serialized_end=5481
# @@protoc_insertion_point(module_scope)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: notification/v2/notification_service.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'notification/v2/notification_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...util.v1 import uuid_pb2 as util_dot_v1_dot_uuid__pb2
from . import notification_pb2 as notification_dot_v2_dot_notification__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*notification/v2/notification_service.proto\x12\x0fnotification.v2\x1a\x12util/v1/uuid.proto\x1a\"notification/v2/notification.proto\x1a\x1fgoogle/protobuf/timestamp.proto\" \n\x1eRemoveFcmTokenFromUserResponse\"N\n\x1dRemoveFcmTokenFromUserRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\x12\r\n\x05token\x18\x02 \x01(\t\"\x1b\n\x19\x41\x64\x64\x46\x63mTokenToUserResponse\"I\n\x18\x41\x64\x64\x46\x63mTokenToUserRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\x12\r\n\x05token\x18\x02 \x01(\t\"P\n\x18GetNotificationsResponse\x12\x34\n\rnotifications\x18\x01 \x03(\x0b\x32\x1d.notification.v2.Notification\"o\n\x17GetNotificationsRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\x12\x34\n\x10\x63reated_at_after\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp2\xe5\x02\n\x13NotificationService\x12g\n\x10GetNotifications\x12(.notification.v2.GetNotificationsRequest\x1a).notification.v2.GetNotificationsResponse\x12j\n\x11\x41\x64\x64\x46\x63mTokenToUser\x12).notification.v2.AddFcmTokenToUserRequest\x1a*.notification.v2.AddFcmTokenToUserResponse\x12y\n\x16RemoveFcmTokenFromUser\x12..notification.v2.RemoveFcmTokenFromUserRequest\x1a/.notification.v2.RemoveFcmTokenFromUserResponseB\x88\x01\n\x0fnotification.v2B\x18NotificationServiceProtoP\x01\xa2\x02\x03NXX\xaa\x02\x0fNotification.V2\xca\x02\x0fNotification\\V2\xe2\x02\x1bNotification\\V2\\GPBMetadata\xea\x02\x10Notification::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'notification.v2.notification_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017notification.v2B\030NotificationServiceProtoP\001\242\002\003NXX\252\002\017Notification.V2\312\002\017Notification\\V2\342\002\033Notification\\V2\\GPBMetadata\352\002\020Notification::V2'
  _globals['_REMOVEFCMTOKENFROMUSERRESPONSE']._serialized_start=152
  _globals['_REMOVEFCMTOKENFROMUSERRESPONSE']._serialized_end=184
  _globals['_REMOVEFCMTOKENFROMUSERREQUEST']._serialized_start=186
  _globals['_REMOVEFCMTOKENFROMUSERREQUEST']._serialized_end=264
  _globals['_ADDFCMTOKENTOUSERRESPONSE']._serialized_start=266
  _globals['_ADDFCMTOKENTOUSERRESPONSE']._serialized_end=293
  _globals['_ADDFCMTOKENTOUSERREQUEST']._serialized_start=295
  _globals['_ADDFCMTOKENTOUSERREQUEST']._serialized_end=368
  _globals['_GETNOTIFICATIONSRESPONSE']._serialized_start=370
  _globals['_GETNOTIFICATIONSRESPONSE']._serialized_end=450
  _globals['_GETNOTIFICATIONSREQUEST']._serialized_start=452
  _globals['_GETNOTIFICATIONSREQUEST']._serialized_end=563
  _globals['_NOTIFICATIONSERVICE']._serialized_start=566
  _globals['_NOTIFICATIONSERVICE']._serialized_end=923
# @@protoc_insertion_point(module_scope)



"""Cloud API interaction class for Aira Home."""
# cloud.py
from .device.heat_pump.statistics.v1 import service_pb2 as stats_service_pb2, service_pb2_grpc as stats_service_pb2_grpc
from .device.heat_pump.cloud.v1 import service_pb2 as cloud_service_pb2, service_pb2_grpc as cloud_service_pb2_grpc
from .device.heat_pump.command.v1.command_source_pb2 import CommandSource
from .device.heat_pump.command.v1 import command_pb2
from .utils import Utils, UnknownCommandException, CommandUtils
from .device.v1 import devices_pb2, devices_pb2_grpc
from grpc import secure_channel, ssl_channel_credentials
from google.protobuf.message import Message
from .util.v1.uuid_pb2 import Uuid as Uuid1
from datetime import datetime
from .auth import CognitoAuth
from enum import Enum
import os


class Cloud:
    """A client to interact with the Aira Home API using the cloud."""
    
    def __init__(self, airahome_instance):
        """Initialize Cloud with reference to parent AiraHome instance."""
        self._ah_i = airahome_instance

        # Initialize cognitoauth instance
        self._auth = CognitoAuth(self._ah_i.user_pool_id, self._ah_i.client_id)

        # Initialize gRPC channel and stubs
        channel_options = [                             # Channel options to keep the connection alive
            ('grpc.keepalive_time_ms', 10000),          # Send keepalive ping every 10 seconds
            ('grpc.keepalive_timeout_ms', 5000),        # Wait 5 seconds for keepalive response
            ('grpc.keepalive_permit_without_calls', 1), # Allow keepalive pings without active RPCs
        ]
        self._channel = secure_channel(self._ah_i.aira_backend, ssl_channel_credentials(), options=channel_options)
        self._devices_stub = devices_pb2_grpc.DevicesServiceStub(self._channel)
        self._cloud_service_stub = cloud_service_pb2_grpc.HeatPumpCloudServiceStub(self._channel)
        self._stats_service_stub = stats_service_pb2_grpc.HeatPumpStatisticsServiceStub(self._channel)

    ###
    # Helper methods
    ###

    def _get_id_token(self):
        """Get the ID token from the TokenManager."""
        tokens = self._auth.get_tokens()
        if tokens:
            return tokens.get_id_token()
        return None

    def _get_metadatas(self) -> tuple[tuple[str, str], ...]:
        """Create Metadatas instance with the current settings."""
        id_token = self._get_id_token()
        metadata = (
            ('authorization', f'Bearer {id_token}'),
            ('user-agent', self._ah_i.user_agent),
            ('app-package', self._ah_i.app_package),
            ('app-version', self._ah_i.app_version)
        )
        return metadata

    def call_service(self, stub, method_name: str, request, timeout: int = -1, raw: bool = False) -> Message | dict:
        """Call a gRPC service method with the given request."""
        # Get the method from the stub dynamically
        method = getattr(stub, method_name)
        if timeout < 0:
            timeout = self._ah_i.grpc_timeout
        # Call the method with the request, timeout, and generated metadata
        response = method(
            request,
            timeout=timeout,
            metadata=self._get_metadatas()
        )

        if raw:
            return response
        
        return Utils.convert_to_dict(response)

    def get_tokens(self):
        """Get the TokenManager instance if available."""
        return self._auth.get_tokens()

    ###
    # Auth methods
    ###
    
    def login_with_credentials(self, username: str, password: str):
        """Login using username and password."""
        return self._auth.login_credentials(username, password)

    def login_with_tokens(self, id_token: str, access_token: str, refresh_token: str):
        """Login using existing tokens."""
        return self._auth.login_tokens(id_token, access_token, refresh_token)

    ###
    # Heatpump methods
    ###

    # Heatpump ro methods
    def get_devices(self, raw: bool = False) -> dict | Message:
        """
        Returns the list of devices associated with the authenticated user.
        Use `raw=True` to get the raw gRPC response.

        ### Parameters

        `raw` : bool, optional
            If True, returns the raw gRPC response. Defaults to False.

        ### Returns

        dict | GetDevicesResponse (Message)
            When `raw=False`: A dictionary containing the list of devices with their details.
            When `raw=True`: The raw gRPC GetDevicesResponse protobuf message.
            
            Example of the expected response content regardless of the `raw` parameter:
            ```
{'devices': [{'id': {'value': '123e4567-e89b-12d3-a456-426614174000'},
              'online': {'online': True,
                         'time': datetime.datetime(2025, 9, 18, 19, 40, 22, 363000)}}]}
            ```
        
        ### Examples

        >>> AiraHome().cloud.get_devices(raw=False)
        """
        
        request = devices_pb2.GetDevicesRequest()

        return self.call_service(
            self._devices_stub, 
            "GetDevices", 
            request,
            raw=raw
        )

    def get_device_details(self, device_id: str, raw: bool = False) -> dict | Message: # uuid_format: v1
        """
        Returns the details (including the certificate used for ble) of a specific device by its ID.
        Use `raw=True` to get the raw gRPC response.

        ### Parameters

        `device_id` : str
            Heat pump id in UUID format. E.g., '123e4567-e89b-12d3-a456-426614174000'.

        `raw` : bool, optional
            If True, returns the raw gRPC response. Defaults to False.

        ### Returns

        dict | GetDeviceDetailsResponse (Message)
            When `raw=False`: A dictionary containing some details for the given device.
            When `raw=True`: The raw gRPC GetDevicesResponse protobuf message.
            
            Example of the expected response content regardless of the `raw` parameter:
            ```
{'heat_pump': {'certificate': {'certificate_pem': '-----BEGIN '
                                                  'CERTIFICATE-----\n'
                                                  '...certificate content...\n'
                                                  '-----END '
                                                  'CERTIFICATE-----\n'},
               'id': {'value': '123e4567-e89b-12d3-a456-426614174000'},
               'tank_size': 'WATER_TANK_SIZE_300_LITERS'}}
            ```
        
        ### Examples

        >>> AiraHome().cloud.get_device_details("123e4567-e89b-12d3-a456-426614174000", raw=False)
        """

        _id = Utils.convert_uuid_from_v2(device_id)

        request = devices_pb2.GetDeviceDetailsRequest(id=_id)

        return self.call_service(
            self._devices_stub,
            "GetDeviceDetails",
            request,
            raw=raw
        )

    def get_states(self, device_ids: str | list[str], raw: bool = False) -> dict | Message: # uuid_format: v1
        """
        Returns the states of a specific device by its ID or a list of devices by their IDs.
        Use `raw=True` to get the raw gRPC response.

        ### Parameters

        `device_ids` : str | list[str]
            Heat pump(s) id(s) in UUID format. E.g., '123e4567-e89b-12d3-a456-426614174000'.

        `raw` : bool, optional
            If True, returns the raw gRPC response. Defaults to False.

        ### Returns

        dict | GetStatesResponse (Message)
            When `raw=False`: A dictionary containing most states for the given device.
            When `raw=True`: The raw gRPC GetDevicesResponse protobuf message.
            
            Example of the expected response content regardless of the `raw` parameter:
            ```
{'heat_pump_states': [{'allowed_pump_mode_state': 'PUMP_MODE_STATE_IDLE',
                       'aws_iot_received_time': datetime.datetime(2025, 9, 23, 7, 17, 57, 122747),
                       'configured_pump_modes': 'PUMP_MODE_STATE_HEATING_COOLING',
                       'cool_curve_deltas': {},
                       'cool_curves': {...},
                       'current_hot_water_temperature': 23.4,
                       'current_outdoor_temperature': 22.5,
                       'current_pump_mode_state': {...}
                       ...]}
            ```
        
        ### Examples

        >>> AiraHome().cloud.get_states("123e4567-e89b-12d3-a456-426614174000", raw=False)
        """
        
        if isinstance(device_ids, list):
            heat_pump_ids = []
            for device_id in device_ids:
                heat_pump_ids.append(Utils.convert_uuid_from_v2(device_id))
        else:
            heat_pump_ids = [Utils.convert_uuid_from_v2(device_ids)]

        request = devices_pb2.GetStatesRequest(heat_pump_ids=heat_pump_ids)
        
        return self.call_service(
            self._devices_stub,
            "GetStates",
            request,
            raw=raw
        )

    def get_insights(self,
                     heat_pump_id: str,
                     granularity: Enum | int,
                     start_time: datetime | None = None,
                     end_time: datetime | None = None,
                     raw: bool = False) -> dict | Message: # uuid_format: v2
        """
        Returns insights for a specific heat pump within a given time range. If no time range is provided, it defaults to whatever the backend returns.
        Use `raw=True` to get the raw gRPC response.

        ### Parameters

        `heat_pump_id` : str
            Heat pump id in UUID format. E.g., '123e4567-e89b-12d3-a456-426614174000'.

        `granularity` : Enum | int
            The granularity of the insights, can be unspecified, hourly, daily, monthly. Use pyairahome.enums.Granularity.* for values.

        `start_time` : datetime, optional
            The start time for the insights. If None, defaults to the backend's default.

        `end_time` : datetime, optional
            The end time for the insights. If None, defaults to the backend's default.

        `raw` : bool, optional
            If True, returns the raw gRPC response. Defaults to False.

        ### Returns
    
        dict | GetHeatPumpInsightsResponse (Message)
            When `raw=False`: A dictionary containing insights for the given heat pump.
            When `raw=True`: The raw gRPC GetHeatPumpInsightsResponse protobuf message.
            
            Example of the expected response content regardless of the `raw` parameter:
            ```
{'insights': [{'delivered_heat_wh': 11127.97278440123,
               'energy_consumption_wh': 4900,
               'start_time': {'day': 21, 'month': 9, 'year': 2025}},
              {'delivered_heat_wh': 11529.97278440123,
               'energy_consumption_wh': 3000,
               'start_time': {'day': 22, 'month': 9, 'year': 2025}},
              {'delivered_heat_wh': 436.3242614670768,
               'energy_consumption_wh': 200,
               'start_time': {'day': 23, 'month': 9, 'year': 2025}}]}
            ```
        
        ### Examples

        >>> from pyairahome.enums import Granularity
        >>> AiraHome().cloud.get_insights("123e4567-e89b-12d3-a456-426614174000", granularity=Granularity.GRANULARITY_DAILY, start_time=datetime(2025, 9, 21), end_time=datetime(2025, 9, 23), raw=False)
        """

        if start_time is not None:
            start_time = Utils.datetime_to_localdatetime(start_time)
        if end_time is not None:
            end_time = Utils.datetime_to_localdatetime(end_time)
        
        request = stats_service_pb2.GetHeatPumpInsightsRequest(
            heat_pump_id=Utils.convert_str_to_v2(heat_pump_id),
            start_time=start_time,
            end_time_exclusive=end_time,
            granularity=getattr(granularity, 'value', granularity)
        )

        return self.call_service(
            self._stats_service_stub,
            "GetHeatPumpInsights",
            request,
            raw=raw
        )

    # Heatpump wo methods
    def send_command(self, device_id: str, command_in, timestamp: float | int | None = None, raw: bool = False, **kwargs): # uuid_format: v1
        """
        Send a command to a specific device by its ID. The command must be one of the supported commands. Additional parameters for the command can be passed as keyword arguments.
        Use `raw=True` to get the raw gRPC response.

        ### Parameters

        `device_id` : str
            Heat pump id in UUID format. E.g., '123e4567-e89b-12d3-a456-426614174000'.
        
        `command_in` : any
            The command to send. Must be one of the supported commands. Use method `get_command_list()` to get available commands.

        `timestamp` : float | int | None, optional
            The timestamp for the command. If None, uses the current time. Can be a float (seconds since epoch), int (seconds since epoch), or datetime object.
        
        `raw` : bool, optional
            If True, returns the raw gRPC response. Defaults to False.

        `**kwargs` : dict
            Additional parameters for the command. The keys must match the field names of the command.

        ### Returns

        dict | SendCommandResponse (Message)
            When `raw=False`: A dictionary containing the result of the command.
            When `raw=True`: The raw gRPC SendCommandResponse protobuf message.
            
            Example of the expected response content regardless of the `raw` parameter:
            ```
{'command_id': {'value': '46ef4514-fe04-deb0-ffd8-7d07156975f2'}}
            ```
        
        ### Examples
        >>> AiraHome().cloud.send_command("123e4567-e89b-12d3-a456-426614174000", "acknowledge_errors", raw=False)
        """

        heat_pump_id = Utils.convert_uuid_from_v2(device_id)
        
        _time = Utils.convert_to_timestamp(timestamp)

        if isinstance(command_in, str) and command_in in self._ah_i.command_list:
            # Get the command class dynamically
            command_class = type(getattr(command_pb2.Command(), CommandUtils.camel_case_to_snake_case(command_in)))

            # TODO understand how aira messages (not built-in python types) interact with this
            # Prepare the fields for the command
            fields = {field["name"]: field["type"](kwargs[field["name"]]) for field in self._ah_i.get_command_fields(command_in, raw=True) if field["name"] in kwargs}
            
            # Create the command instance
            command = command_pb2.Command(command_id=Uuid1(value=os.urandom(16)),
                                          **{CommandUtils.camel_case_to_snake_case(command_in): command_class(**fields)},
                                          time=_time,
                                          command_source=CommandSource.COMMAND_SOURCE_APP_CONTROL) # Create the command instance dynamically
            # source is app since we are using the app endpoints
        else:
            raise UnknownCommandException(f"Unknown command: {command_in}. Allowed commands are: {self._ah_i.command_list}")

        request = cloud_service_pb2.SendCommandRequest(heat_pump_id=heat_pump_id,
                                                       command=command)

        return self.call_service(
            self._cloud_service_stub,
            "SendCommand",
            request,
            raw=raw
        )
    
    # Heatpump stream methods
    def stream_command_progress(self, command_id: str, raw: bool = False) : # uuid_format: v1
        """
        Stream the progress of a command. Returns a generator object that yields updates as they are received until success or failure.
        Use `raw=True` to get the raw gRPC response.

        ### Parameters

        `command_id` : str
            Command id in UUID format. E.g., '46ef4514-fe04-deb0-ffd8-7d07156975f2'.
        
        `raw` : bool, optional
            If True, yields the raw gRPC response. Defaults to False.
        
        ### Yields

        dict | StreamCommandProgressResponse (Message)
            When `raw=False`: A dictionary containing the progress update of the command.
            When `raw=True`: The raw gRPC StreamCommandProgressResponse protobuf message.
            
            Example of the expected response content regardless of the `raw` parameter:
            ```
{'command_progress': {'aws_iot_received_time': datetime.datetime(2025, 9, 26, 15, 38, 49, 214993),
                      'command_id': {'value': '46ef4514-fe04-deb0-ffd8-7d07156975f2'},
                      'succeeded': {},
                      'time': datetime.datetime(2025, 9, 26, 15, 38, 47, 269748)}}
            ```

        ### Examples

        >>> for update in AiraHome().cloud.stream_command_progress("46ef4514-fe04-deb0-ffd8-7d07156975f2", raw=False):
        """

        request = cloud_service_pb2.StreamCommandProgressRequest(command_id=Utils.convert_uuid_from_v2(command_id))

        response = self.call_service(
            self._cloud_service_stub,
            "StreamCommandProgress",
            request,
            raw=True # always raw since we need to map the generator
        )

        if raw:
            return response

        return map(Utils.convert_to_dict, response)

    def stream_states(self, device_ids, raw: bool = False): # uuid_format: v1
        raise NotImplementedError("stream_states has been removed since it was not working. Please use get_states instead.")


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: schedule/v1/action.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'schedule/v1/action.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18schedule/v1/action.proto\x12\x0bschedule.v1\"\x13\n\x11SetAntiLegionella\"\x0e\n\x0cPostAwayMode\".\n\x0bSetAwayMode\x12\x1f\n\x17target_room_temperature\x18\x01 \x01(\x02\"\x19\n\x0bSetDhwBoost\x12\n\n\x02on\x18\x01 \x01(\x08\"\x97\x01\n\x14SetRoomSetpointDelta\x12\x34\n\x04zone\x18\x01 \x01(\x0e\x32&.schedule.v1.SetRoomSetpointDelta.Zone\x12\x13\n\x0btemperature\x18\x02 \x01(\x02\"4\n\x04Zone\x12\x14\n\x10ZONE_UNSPECIFIED\x10\x00\x12\n\n\x06ZONE_1\x10\x01\x12\n\n\x06ZONE_2\x10\x02\"%\n\x0eSetDhwSetpoint\x12\x13\n\x0btemperature\x18\x01 \x01(\x02\"*\n\x13SetDhwSetpointDelta\x12\x13\n\x0btemperature\x18\x01 \x01(\x02\")\n\x12SetRoomSupplyDelta\x12\x13\n\x0btemperature\x18\x01 \x01(\x02\"\x9d\x04\n\x11SetFerroampConfig\x12\x37\n\x04mode\x18\x01 \x01(\x0e\x32).schedule.v1.SetFerroampConfig.SystemMode\x12>\n\x0bgrid_config\x18\x02 \x01(\x0b\x32).schedule.v1.SetFerroampConfig.GridConfig\x12\x44\n\x0e\x62\x61ttery_config\x18\x03 \x01(\x0b\x32,.schedule.v1.SetFerroampConfig.BatteryConfig\x1a\x32\n\rBatteryConfig\x12\x0e\n\x06\x63harge\x18\x01 \x01(\x08\x12\x11\n\tdischarge\x18\x02 \x01(\x08\x1as\n\nGridConfig\x12\x14\n\x0climit_import\x18\x01 \x01(\x08\x12\x14\n\x0climit_export\x18\x02 \x01(\x08\x12\x1b\n\x13power_threshold_low\x18\x03 \x01(\x02\x12\x1c\n\x14power_threshold_high\x18\x04 \x01(\x02\"\x9f\x01\n\nSystemMode\x12\x1b\n\x17SYSTEM_MODE_UNSPECIFIED\x10\x00\x12\x17\n\x13SYSTEM_MODE_DEFAULT\x10\x01\x12 \n\x1cSYSTEM_MODE_SELF_CONSUMPTION\x10\x02\x12\x1c\n\x18SYSTEM_MODE_PEAK_SHAVING\x10\x03\x12\x1b\n\x17SYSTEM_MODE_MEASUREMENT\x10\x04\"\x12\n\x10SetChargeBattery\"\x0e\n\x0cSetNightMode\"O\n\x11SetHeatCurveDelta\x12\n\n\x02p1\x18\x01 \x01(\x02\x12\n\n\x02p2\x18\x02 \x01(\x02\x12\n\n\x02p3\x18\x03 \x01(\x02\x12\n\n\x02p4\x18\x04 \x01(\x02\x12\n\n\x02p5\x18\x05 \x01(\x02\"\xe2\x05\n\x06\x41\x63tion\x12\x44\n\x17set_room_setpoint_delta\x18\x01 \x01(\x0b\x32!.schedule.v1.SetRoomSetpointDeltaH\x00\x12\x42\n\x16set_dhw_setpoint_delta\x18\x02 \x01(\x0b\x32 .schedule.v1.SetDhwSetpointDeltaH\x00\x12\x31\n\rset_dhw_boost\x18\x03 \x01(\x0b\x32\x18.schedule.v1.SetDhwBoostH\x00\x12\x37\n\x10set_dhw_setpoint\x18\x04 \x01(\x0b\x32\x1b.schedule.v1.SetDhwSetpointH\x00\x12\x31\n\rset_away_mode\x18\x05 \x01(\x0b\x32\x18.schedule.v1.SetAwayModeH\x00\x12=\n\x13set_anti_legionella\x18\x06 \x01(\x0b\x32\x1e.schedule.v1.SetAntiLegionellaH\x00\x12@\n\x15set_room_supply_delta\x18\x07 \x01(\x0b\x32\x1f.schedule.v1.SetRoomSupplyDeltaH\x00\x12\x33\n\x0epost_away_mode\x18\x08 \x01(\x0b\x32\x19.schedule.v1.PostAwayModeH\x00\x12=\n\x13set_ferroamp_config\x18\t \x01(\x0b\x32\x1e.schedule.v1.SetFerroampConfigH\x00\x12;\n\x12set_charge_battery\x18\n \x01(\x0b\x32\x1d.schedule.v1.SetChargeBatteryH\x00\x12>\n\x14set_heat_curve_delta\x18\x0b \x01(\x0b\x32\x1e.schedule.v1.SetHeatCurveDeltaH\x00\x12\x33\n\x0eset_night_mode\x18\x0c \x01(\x0b\x32\x19.schedule.v1.SetNightModeH\x00\x42\x08\n\x06group0Bg\n\x0bschedule.v1B\x0b\x41\x63tionProtoP\x01\xa2\x02\x03SXX\xaa\x02\x0bSchedule.V1\xca\x02\x0bSchedule\\V1\xe2\x02\x17Schedule\\V1\\GPBMetadata\xea\x02\x0cSchedule::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'schedule.v1.action_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\013schedule.v1B\013ActionProtoP\001\242\002\003SXX\252\002\013Schedule.V1\312\002\013Schedule\\V1\342\002\027Schedule\\V1\\GPBMetadata\352\002\014Schedule::V1'
  _globals['_SETANTILEGIONELLA']._serialized_start=41
  _globals['_SETANTILEGIONELLA']._serialized_end=60
  _globals['_POSTAWAYMODE']._serialized_start=62
  _globals['_POSTAWAYMODE']._serialized_end=76
  _globals['_SETAWAYMODE']._serialized_start=78
  _globals['_SETAWAYMODE']._serialized_end=124
  _globals['_SETDHWBOOST']._serialized_start=126
  _globals['_SETDHWBOOST']._serialized_end=151
  _globals['_SETROOMSETPOINTDELTA']._serialized_start=154
  _globals['_SETROOMSETPOINTDELTA']._serialized_end=305
  _globals['_SETROOMSETPOINTDELTA_ZONE']._serialized_start=253
  _globals['_SETROOMSETPOINTDELTA_ZONE']._serialized_end=305
  _globals['_SETDHWSETPOINT']._serialized_start=307
  _globals['_SETDHWSETPOINT']._serialized_end=344
  _globals['_SETDHWSETPOINTDELTA']._serialized_start=346
  _globals['_SETDHWSETPOINTDELTA']._serialized_end=388
  _globals['_SETROOMSUPPLYDELTA']._serialized_start=390
  _globals['_SETROOMSUPPLYDELTA']._serialized_end=431
  _globals['_SETFERROAMPCONFIG']._serialized_start=434
  _globals['_SETFERROAMPCONFIG']._serialized_end=975
  _globals['_SETFERROAMPCONFIG_BATTERYCONFIG']._serialized_start=646
  _globals['_SETFERROAMPCONFIG_BATTERYCONFIG']._serialized_end=696
  _globals['_SETFERROAMPCONFIG_GRIDCONFIG']._serialized_start=698
  _globals['_SETFERROAMPCONFIG_GRIDCONFIG']._serialized_end=813
  _globals['_SETFERROAMPCONFIG_SYSTEMMODE']._serialized_start=816
  _globals['_SETFERROAMPCONFIG_SYSTEMMODE']._serialized_end=975
  _globals['_SETCHARGEBATTERY']._serialized_start=977
  _globals['_SETCHARGEBATTERY']._serialized_end=995
  _globals['_SETNIGHTMODE']._serialized_start=997
  _globals['_SETNIGHTMODE']._serialized_end=1011
  _globals['_SETHEATCURVEDELTA']._serialized_start=1013
  _globals['_SETHEATCURVEDELTA']._serialized_end=1092
  _globals['_ACTION']._serialized_start=1095
  _globals['_ACTION']._serialized_end=1833
# @@protoc_insertion_point(module_scope)


"""Command utilities for the Aira Home library."""
# utils/commands.py
import importlib
import pkgutil


class CommandUtils:
    @staticmethod
    def camel_case_to_snake_case(name):
        """Convert CamelCase to snake_case."""
        return "".join(["_" + i.lower() if i.isupper() else i for i in name]).lstrip("_")

    @staticmethod
    def snake_case_to_camel_case(name):
        """Convert snake_case to CamelCase."""
        return "".join(word.title() for word in name.split("_"))

    @staticmethod
    def find_in_modules(package_name):
        # Import the package dynamically
        package = importlib.import_module(package_name)
        
        # Get the package"s path
        package_path = package.__path__
        
        # Iterate over submodules
        commands = []
        for _, module_name, is_pkg in pkgutil.iter_modules(package_path):
            if not is_pkg and not "grpc" in module_name:
                command = CommandUtils.snake_case_to_camel_case(module_name)[:-3]  # Remove the trailing "_pb2"
                if command == "Command":
                    continue
                
                commands.append(command)

        return commands

    @staticmethod
    def get_message_field(command, package_name, raw: bool = False):
        # Convert command name to snake_case for the file name
        command_file = CommandUtils.camel_case_to_snake_case(command) + "_pb2"

        # Import the command module dynamically
        module = importlib.import_module(f"{package_name}.{command_file}")
        # Get the command class
        fields = []
        for item in dir(module):
            if not item.isupper() and "_" not in item:
                # Get command fields
                descriptor = getattr(module, item).DESCRIPTOR
                if hasattr(descriptor, "fields_by_name"):
                    for field_name, field_type in descriptor.fields_by_name.items():
                        field_data = {
                            "name": field_name,
                            "type": type(getattr(getattr(module, item)(), field_name)) if raw else type(getattr(getattr(module, item)(), field_name)).__name__,
                            "full_name": field_type.full_name,
                            "repeated": field_type.is_repeated,
                            "required": field_type.is_required,
                            "index": field_type.index,
                            "oneof": None
                        }
                        if hasattr(field_type, "containing_oneof") and field_type.containing_oneof is not None:
                            field_data["oneof"] = field_type.containing_oneof.full_name
                        fields.append(field_data)
        return fields


"""Class containing default settings for the application."""
# config/settings.py


class Settings:
    USER_POOL_IDS = ["eu-north-1_cnqyjWtbz", "eu-north-1_EyCYO6SAa", "eu-north-1_k0IgmZxLJ"]
    CLIENT_ID = "5eehn0b5d6fsg28rjc5p1u0vi6"
    AIRA_BACKEND = "engagementbff.prod.airahome.com:443"
    USER_AGENT = "AiraApp 1.4.10"
    APP_PACKAGE = "com.airahome.aira"
    APP_VERSION = "1.4.10"
    GRPC_TIMEOUT = 8  # seconds
    COMMAND_PACKAGE = "pyairahome.device.heat_pump.command.v1"
    INSECURE_CHARACTERISTIC = "00000008-0000-a112-a000-a112a0000000"
    SECURE_CHARACTERISTIC = "00000002-0000-a112-a000-a112a0000000"
    DEFAULT_UUID_SELECTION = 0  # 0 = first
    BLE_NOTIFY_TIMEOUT = 8  # seconds
    MAX_BLE_CHUNK_SIZE = 256 # bytes


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: util/v1/uuid.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'util/v1/uuid.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12util/v1/uuid.proto\x12\x07util.v1\"\x15\n\x04Uuid\x12\r\n\x05value\x18\x01 \x01(\x0c\x42Q\n\x07util.v1B\tUuidProtoP\x01\xa2\x02\x03UXX\xaa\x02\x07Util.V1\xca\x02\x07Util\\V1\xe2\x02\x13Util\\V1\\GPBMetadata\xea\x02\x08Util::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'util.v1.uuid_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\007util.v1B\tUuidProtoP\001\242\002\003UXX\252\002\007Util.V1\312\002\007Util\\V1\342\002\023Util\\V1\\GPBMetadata\352\002\010Util::V1'
  _globals['_UUID']._serialized_start=31
  _globals['_UUID']._serialized_end=52
# @@protoc_insertion_point(module_scope)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/heat_pump/command/v1/set_telemetry_interval.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'device/heat_pump/command/v1/set_telemetry_interval.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8device/heat_pump/command/v1/set_telemetry_interval.proto\x12\x1b\x64\x65vice.heat_pump.command.v1\x1a\x1egoogle/protobuf/duration.proto\"\xd8\x03\n\x14SetTelemetryInterval\x12\x34\n\x11sampling_interval\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12W\n\x0etelemetry_type\x18\x02 \x01(\x0e\x32?.device.heat_pump.command.v1.SetTelemetryInterval.TelemetryType\"\xb0\x02\n\rTelemetryType\x12\x1e\n\x1aTELEMETRY_TYPE_UNSPECIFIED\x10\x00\x12 \n\x1cTELEMETRY_TYPE_SENSOR_VALUES\x10\x01\x12\x17\n\x12TELEMETRY_TYPE_DHW\x10\xe9\x07\x12\x1a\n\x15TELEMETRY_TYPE_STATUS\x10\xea\x07\x12\'\n\"TELEMETRY_TYPE_OUTDOOR_UNIT_STATUS\x10\xeb\x07\x12\x1c\n\x17TELEMETRY_TYPE_SETTINGS\x10\xec\x07\x12\x1a\n\x15TELEMETRY_TYPE_OUTPUT\x10\xed\x07\x12\x1c\n\x17TELEMETRY_TYPE_VERSIONS\x10\xee\x07\x12\'\n\"TELEMETRY_TYPE_OUTDOOR_UNIT_OUTPUT\x10\xef\x07*\xdf\x01\n\x19SetTelemetryIntervalError\x12,\n(SET_TELEMETRY_INTERVAL_ERROR_UNSPECIFIED\x10\x00\x12\x31\n-SET_TELEMETRY_INTERVAL_ERROR_TYPE_UNSPECIFIED\x10\x01\x12\x31\n-SET_TELEMETRY_INTERVAL_ERROR_INVALID_INTERVAL\x10\x02\x12.\n*SET_TELEMETRY_INTERVAL_ERROR_VALUE_TOO_LOW\x10\x03\x42\xc3\x01\n\x1b\x64\x65vice.heat_pump.command.v1B\x19SetTelemetryIntervalProtoP\x01\xa2\x02\x03\x44HC\xaa\x02\x1a\x44\x65vice.HeatPump.Command.V1\xca\x02\x1a\x44\x65vice\\HeatPump\\Command\\V1\xe2\x02&Device\\HeatPump\\Command\\V1\\GPBMetadata\xea\x02\x1d\x44\x65vice::HeatPump::Command::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.heat_pump.command.v1.set_telemetry_interval_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033device.heat_pump.command.v1B\031SetTelemetryIntervalProtoP\001\242\002\003DHC\252\002\032Device.HeatPump.Command.V1\312\002\032Device\\HeatPump\\Command\\V1\342\002&Device\\HeatPump\\Command\\V1\\GPBMetadata\352\002\035Device::HeatPump::Command::V1'
  _globals['_SETTELEMETRYINTERVALERROR']._serialized_start=597
  _globals['_SETTELEMETRYINTERVALERROR']._serialized_end=820
  _globals['_SETTELEMETRYINTERVAL']._serialized_start=122
  _globals['_SETTELEMETRYINTERVAL']._serialized_end=594
  _globals['_SETTELEMETRYINTERVAL_TELEMETRYTYPE']._serialized_start=290
  _globals['_SETTELEMETRYINTERVAL_TELEMETRYTYPE']._serialized_end=594
# @@protoc_insertion_point(module_scope)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: schedule/v1/event.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'schedule/v1/event.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import rrule_pb2 as schedule_dot_v1_dot_rrule__pb2
from . import action_pb2 as schedule_dot_v1_dot_action__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17schedule/v1/event.proto\x12\x0bschedule.v1\x1a\x17schedule/v1/rrule.proto\x1a\x18schedule/v1/action.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\"\xae\x02\n\x05\x45vent\x12/\n\x0b\x65vent_start\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\tevent_end\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12!\n\x05rrule\x18\x03 \x01(\x0b\x32\x12.schedule.v1.RRule\x12#\n\x06\x61\x63tion\x18\x04 \x01(\x0b\x32\x13.schedule.v1.Action\x12\x16\n\x0e\x65vent_start_dt\x18\x05 \x01(\t\x12\x14\n\x0c\x65vent_end_dt\x18\x06 \x01(\t\x12\x31\n\x0eremaining_time\x18\x07 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x0e\n\x06\x61\x63tive\x18\x08 \x01(\x08\x12\x0c\n\x04name\x18\t \x01(\t\",\n\x06\x45vents\x12\"\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x12.schedule.v1.EventBf\n\x0bschedule.v1B\nEventProtoP\x01\xa2\x02\x03SXX\xaa\x02\x0bSchedule.V1\xca\x02\x0bSchedule\\V1\xe2\x02\x17Schedule\\V1\\GPBMetadata\xea\x02\x0cSchedule::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'schedule.v1.event_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\013schedule.v1B\nEventProtoP\001\242\002\003SXX\252\002\013Schedule.V1\312\002\013Schedule\\V1\342\002\027Schedule\\V1\\GPBMetadata\352\002\014Schedule::V1'
  _globals['_EVENT']._serialized_start=157
  _globals['_EVENT']._serialized_end=459
  _globals['_EVENTS']._serialized_start=461
  _globals['_EVENTS']._serialized_end=505
# @@protoc_insertion_point(module_scope)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/heat_pump/state/v1/heat.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'device/heat_pump/state/v1/heat.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$device/heat_pump/state/v1/heat.proto\x12\x19\x64\x65vice.heat_pump.state.v1\"8\n\x04Heat\x12\x15\n\x0btemperature\x18\x01 \x01(\x02H\x00\x12\x0f\n\x05level\x18\x02 \x01(\x02H\x00\x42\x08\n\x06group0B\xa9\x01\n\x19\x64\x65vice.heat_pump.state.v1B\tHeatProtoP\x01\xa2\x02\x03\x44HS\xaa\x02\x18\x44\x65vice.HeatPump.State.V1\xca\x02\x18\x44\x65vice\\HeatPump\\State\\V1\xe2\x02$Device\\HeatPump\\State\\V1\\GPBMetadata\xea\x02\x1b\x44\x65vice::HeatPump::State::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.heat_pump.state.v1.heat_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031device.heat_pump.state.v1B\tHeatProtoP\001\242\002\003DHS\252\002\030Device.HeatPump.State.V1\312\002\030Device\\HeatPump\\State\\V1\342\002$Device\\HeatPump\\State\\V1\\GPBMetadata\352\002\033Device::HeatPump::State::V1'
  _globals['_HEAT']._serialized_start=67
  _globals['_HEAT']._serialized_end=123
# @@protoc_insertion_point(module_scope)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: schedule/v1/schedule.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'schedule/v1/schedule.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import event_pb2 as schedule_dot_v1_dot_event__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1aschedule/v1/schedule.proto\x12\x0bschedule.v1\x1a\x17schedule/v1/event.proto\"\xb9\x07\n\x08Schedule\x12?\n customer_room_temp_setback_zone1\x18\x01 \x01(\x0b\x32\x13.schedule.v1.EventsH\x00\x12?\n customer_room_temp_setback_zone2\x18\x02 \x01(\x0b\x32\x13.schedule.v1.EventsH\x00\x12:\n\x1bsmart_room_temp_delta_zone1\x18\x03 \x01(\x0b\x32\x13.schedule.v1.EventsH\x00\x12:\n\x1bsmart_room_temp_delta_zone2\x18\x04 \x01(\x0b\x32\x13.schedule.v1.EventsH\x00\x12\x36\n\x17\x63ustomer_dhw_temp_delta\x18\x05 \x01(\x0b\x32\x13.schedule.v1.EventsH\x00\x12\x33\n\x14smart_dhw_temp_delta\x18\x06 \x01(\x0b\x32\x13.schedule.v1.EventsH\x00\x12$\n\x05\x62oost\x18\x07 \x01(\x0b\x32\x13.schedule.v1.EventsH\x00\x12\x30\n\x11\x63ustomer_dhw_temp\x18\x08 \x01(\x0b\x32\x13.schedule.v1.EventsH\x00\x12(\n\taway_mode\x18\t \x01(\x0b\x32\x13.schedule.v1.EventsH\x00\x12.\n\x0f\x61nti_legionella\x18\n \x01(\x0b\x32\x13.schedule.v1.EventsH\x00\x12<\n\x1dsmart_room_supply_delta_zone1\x18\x0b \x01(\x0b\x32\x13.schedule.v1.EventsH\x00\x12<\n\x1dsmart_room_supply_delta_zone2\x18\x0c \x01(\x0b\x32\x13.schedule.v1.EventsH\x00\x12\x31\n\x12smart_power_config\x18\r \x01(\x0b\x32\x13.schedule.v1.EventsH\x00\x12\x36\n\x17\x63ustomer_charge_battery\x18\x0e \x01(\x0b\x32\x13.schedule.v1.EventsH\x00\x12;\n\x1csmart_heat_curve_delta_zone1\x18\x0f \x01(\x0b\x32\x13.schedule.v1.EventsH\x00\x12;\n\x1csmart_heat_curve_delta_zone2\x18\x10 \x01(\x0b\x32\x13.schedule.v1.EventsH\x00\x12)\n\nnight_mode\x18\x11 \x01(\x0b\x32\x13.schedule.v1.EventsH\x00\x42\x08\n\x06group0Bi\n\x0bschedule.v1B\rScheduleProtoP\x01\xa2\x02\x03SXX\xaa\x02\x0bSchedule.V1\xca\x02\x0bSchedule\\V1\xe2\x02\x17Schedule\\V1\\GPBMetadata\xea\x02\x0cSchedule::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'schedule.v1.schedule_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\013schedule.v1B\rScheduleProtoP\001\242\002\003SXX\252\002\013Schedule.V1\312\002\013Schedule\\V1\342\002\027Schedule\\V1\\GPBMetadata\352\002\014Schedule::V1'
  _globals['_SCHEDULE']._serialized_start=69
  _globals['_SCHEDULE']._serialized_end=1022
# @@protoc_insertion_point(module_scope)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: user_account/v2/role.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'user_account/v2/role.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1auser_account/v2/role.proto\x12\x0fuser_account.v2*=\n\x04Role\x12\x14\n\x10ROLE_UNSPECIFIED\x10\x00\x12\x0e\n\nROLE_OWNER\x10\x01\x12\x0f\n\x0bROLE_MEMBER\x10\x02\x42u\n\x0fuser_account.v2B\tRoleProtoP\x01\xa2\x02\x03UXX\xaa\x02\x0eUserAccount.V2\xca\x02\x0eUserAccount\\V2\xe2\x02\x1aUserAccount\\V2\\GPBMetadata\xea\x02\x0fUserAccount::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'user_account.v2.role_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017user_account.v2B\tRoleProtoP\001\242\002\003UXX\252\002\016UserAccount.V2\312\002\016UserAccount\\V2\342\002\032UserAccount\\V2\\GPBMetadata\352\002\017UserAccount::V2'
  _globals['_ROLE']._serialized_start=47
  _globals['_ROLE']._serialized_end=108
# @@protoc_insertion_point(module_scope)